import datetime
from http import HTTPStatus
from typing import Any, Optional, Union
from uuid import UUID

import requests

from ...client import AuthenticatedClient, Client
from ...models.osidb_api_v1_trackers_list_order_item import (
    OsidbApiV1TrackersListOrderItem,
)
from ...models.osidb_api_v1_trackers_list_response_200 import (
    OsidbApiV1TrackersListResponse200,
)
from ...models.osidb_api_v1_trackers_list_type import OsidbApiV1TrackersListType
from ...types import UNSET, Response, Unset

QUERY_PARAMS = {
    "affects__affectedness": str,
    "affects__created_dt": datetime.datetime,
    "affects__created_dt__date": datetime.date,
    "affects__created_dt__date__gte": datetime.date,
    "affects__created_dt__date__lte": datetime.date,
    "affects__created_dt__gt": datetime.datetime,
    "affects__created_dt__gte": datetime.datetime,
    "affects__created_dt__lt": datetime.datetime,
    "affects__created_dt__lte": datetime.datetime,
    "affects__embargoed": bool,
    "affects__flaw__components": list[str],
    "affects__flaw__created_dt": datetime.datetime,
    "affects__flaw__created_dt__date": datetime.date,
    "affects__flaw__created_dt__date__gte": datetime.date,
    "affects__flaw__created_dt__date__lte": datetime.date,
    "affects__flaw__created_dt__gt": datetime.datetime,
    "affects__flaw__created_dt__gte": datetime.datetime,
    "affects__flaw__created_dt__lt": datetime.datetime,
    "affects__flaw__created_dt__lte": datetime.datetime,
    "affects__flaw__cve_id": str,
    "affects__flaw__cwe_id": str,
    "affects__flaw__embargoed": bool,
    "affects__flaw__impact": str,
    "affects__flaw__reported_dt": datetime.datetime,
    "affects__flaw__reported_dt__date": datetime.date,
    "affects__flaw__reported_dt__date__gte": datetime.date,
    "affects__flaw__reported_dt__date__lte": datetime.date,
    "affects__flaw__reported_dt__gt": datetime.datetime,
    "affects__flaw__reported_dt__gte": datetime.datetime,
    "affects__flaw__reported_dt__lt": datetime.datetime,
    "affects__flaw__reported_dt__lte": datetime.datetime,
    "affects__flaw__source": str,
    "affects__flaw__unembargo_dt": datetime.datetime,
    "affects__flaw__updated_dt": datetime.datetime,
    "affects__flaw__updated_dt__date": datetime.date,
    "affects__flaw__updated_dt__date__gte": datetime.date,
    "affects__flaw__updated_dt__date__lte": datetime.date,
    "affects__flaw__updated_dt__gt": datetime.datetime,
    "affects__flaw__updated_dt__gte": datetime.datetime,
    "affects__flaw__updated_dt__lt": datetime.datetime,
    "affects__flaw__updated_dt__lte": datetime.datetime,
    "affects__flaw__uuid": str,
    "affects__impact": str,
    "affects__ps_component": str,
    "affects__ps_module": str,
    "affects__resolution": str,
    "affects__updated_dt": datetime.datetime,
    "affects__updated_dt__date": datetime.date,
    "affects__updated_dt__date__gte": datetime.date,
    "affects__updated_dt__date__lte": datetime.date,
    "affects__updated_dt__gt": datetime.datetime,
    "affects__updated_dt__gte": datetime.datetime,
    "affects__updated_dt__lt": datetime.datetime,
    "affects__updated_dt__lte": datetime.datetime,
    "affects__uuid": str,
    "created_dt": datetime.datetime,
    "created_dt__date": datetime.date,
    "created_dt__date__gte": datetime.date,
    "created_dt__date__lte": datetime.date,
    "created_dt__gt": datetime.datetime,
    "created_dt__gte": datetime.datetime,
    "created_dt__lt": datetime.datetime,
    "created_dt__lte": datetime.datetime,
    "cve_id": str,
    "embargoed": bool,
    "exclude_fields": list[str],
    "external_system_id": str,
    "include_fields": list[str],
    "include_meta_attr": list[str],
    "limit": int,
    "offset": int,
    "order": list[OsidbApiV1TrackersListOrderItem],
    "ps_update_stream": str,
    "resolution": str,
    "status": str,
    "type": OsidbApiV1TrackersListType,
    "updated_dt": datetime.datetime,
    "updated_dt__date": datetime.date,
    "updated_dt__date__gte": datetime.date,
    "updated_dt__date__lte": datetime.date,
    "updated_dt__gt": datetime.datetime,
    "updated_dt__gte": datetime.datetime,
    "updated_dt__lt": datetime.datetime,
    "updated_dt__lte": datetime.datetime,
    "uuid": UUID,
}


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    affects_affectedness: Union[Unset, str] = UNSET,
    affects_created_dt: Union[Unset, datetime.datetime] = UNSET,
    affects_created_dt_date: Union[Unset, datetime.date] = UNSET,
    affects_created_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    affects_created_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    affects_created_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    affects_created_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    affects_created_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    affects_created_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    affects_embargoed: Union[Unset, bool] = UNSET,
    affects_flaw_components: Union[Unset, list[str]] = UNSET,
    affects_flaw_created_dt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_created_dt_date: Union[Unset, datetime.date] = UNSET,
    affects_flaw_created_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    affects_flaw_created_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    affects_flaw_created_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_created_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_created_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_created_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_cve_id: Union[Unset, str] = UNSET,
    affects_flaw_cwe_id: Union[Unset, str] = UNSET,
    affects_flaw_embargoed: Union[Unset, bool] = UNSET,
    affects_flaw_impact: Union[Unset, str] = UNSET,
    affects_flaw_reported_dt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_reported_dt_date: Union[Unset, datetime.date] = UNSET,
    affects_flaw_reported_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    affects_flaw_reported_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    affects_flaw_reported_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_reported_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_reported_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_reported_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_source: Union[Unset, str] = UNSET,
    affects_flaw_unembargo_dt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_updated_dt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_updated_dt_date: Union[Unset, datetime.date] = UNSET,
    affects_flaw_updated_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    affects_flaw_updated_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    affects_flaw_updated_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_updated_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_updated_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_updated_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_uuid: Union[Unset, str] = UNSET,
    affects_impact: Union[Unset, str] = UNSET,
    affects_ps_component: Union[Unset, str] = UNSET,
    affects_ps_module: Union[Unset, str] = UNSET,
    affects_resolution: Union[Unset, str] = UNSET,
    affects_updated_dt: Union[Unset, datetime.datetime] = UNSET,
    affects_updated_dt_date: Union[Unset, datetime.date] = UNSET,
    affects_updated_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    affects_updated_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    affects_updated_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    affects_updated_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    affects_updated_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    affects_updated_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    affects_uuid: Union[Unset, str] = UNSET,
    created_dt: Union[Unset, datetime.datetime] = UNSET,
    created_dt_date: Union[Unset, datetime.date] = UNSET,
    created_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    created_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    created_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    created_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    created_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    created_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    cve_id: Union[Unset, str] = UNSET,
    embargoed: Union[Unset, bool] = UNSET,
    exclude_fields: Union[Unset, list[str]] = UNSET,
    external_system_id: Union[Unset, str] = UNSET,
    include_fields: Union[Unset, list[str]] = UNSET,
    include_meta_attr: Union[Unset, list[str]] = UNSET,
    limit: Union[Unset, int] = UNSET,
    offset: Union[Unset, int] = UNSET,
    order: Union[Unset, list[OsidbApiV1TrackersListOrderItem]] = UNSET,
    ps_update_stream: Union[Unset, str] = UNSET,
    resolution: Union[Unset, str] = UNSET,
    status: Union[Unset, str] = UNSET,
    type_: Union[Unset, OsidbApiV1TrackersListType] = UNSET,
    updated_dt: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_date: Union[Unset, datetime.date] = UNSET,
    updated_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    updated_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    updated_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    uuid: Union[Unset, UUID] = UNSET,
) -> dict[str, Any]:
    headers: dict[str, Any] = client.get_headers()

    params: dict[str, Any] = {}

    params["affects__affectedness"] = affects_affectedness

    json_affects_created_dt: Union[Unset, str] = UNSET
    if not isinstance(affects_created_dt, Unset):
        json_affects_created_dt = affects_created_dt.isoformat()

    params["affects__created_dt"] = json_affects_created_dt

    json_affects_created_dt_date: Union[Unset, str] = UNSET
    if not isinstance(affects_created_dt_date, Unset):
        json_affects_created_dt_date = affects_created_dt_date.isoformat()

    params["affects__created_dt__date"] = json_affects_created_dt_date

    json_affects_created_dt_date_gte: Union[Unset, str] = UNSET
    if not isinstance(affects_created_dt_date_gte, Unset):
        json_affects_created_dt_date_gte = affects_created_dt_date_gte.isoformat()

    params["affects__created_dt__date__gte"] = json_affects_created_dt_date_gte

    json_affects_created_dt_date_lte: Union[Unset, str] = UNSET
    if not isinstance(affects_created_dt_date_lte, Unset):
        json_affects_created_dt_date_lte = affects_created_dt_date_lte.isoformat()

    params["affects__created_dt__date__lte"] = json_affects_created_dt_date_lte

    json_affects_created_dt_gt: Union[Unset, str] = UNSET
    if not isinstance(affects_created_dt_gt, Unset):
        json_affects_created_dt_gt = affects_created_dt_gt.isoformat()

    params["affects__created_dt__gt"] = json_affects_created_dt_gt

    json_affects_created_dt_gte: Union[Unset, str] = UNSET
    if not isinstance(affects_created_dt_gte, Unset):
        json_affects_created_dt_gte = affects_created_dt_gte.isoformat()

    params["affects__created_dt__gte"] = json_affects_created_dt_gte

    json_affects_created_dt_lt: Union[Unset, str] = UNSET
    if not isinstance(affects_created_dt_lt, Unset):
        json_affects_created_dt_lt = affects_created_dt_lt.isoformat()

    params["affects__created_dt__lt"] = json_affects_created_dt_lt

    json_affects_created_dt_lte: Union[Unset, str] = UNSET
    if not isinstance(affects_created_dt_lte, Unset):
        json_affects_created_dt_lte = affects_created_dt_lte.isoformat()

    params["affects__created_dt__lte"] = json_affects_created_dt_lte

    params["affects__embargoed"] = affects_embargoed

    json_affects_flaw_components: Union[Unset, list[str]] = UNSET
    if not isinstance(affects_flaw_components, Unset):
        json_affects_flaw_components = affects_flaw_components

    params["affects__flaw__components"] = json_affects_flaw_components

    json_affects_flaw_created_dt: Union[Unset, str] = UNSET
    if not isinstance(affects_flaw_created_dt, Unset):
        json_affects_flaw_created_dt = affects_flaw_created_dt.isoformat()

    params["affects__flaw__created_dt"] = json_affects_flaw_created_dt

    json_affects_flaw_created_dt_date: Union[Unset, str] = UNSET
    if not isinstance(affects_flaw_created_dt_date, Unset):
        json_affects_flaw_created_dt_date = affects_flaw_created_dt_date.isoformat()

    params["affects__flaw__created_dt__date"] = json_affects_flaw_created_dt_date

    json_affects_flaw_created_dt_date_gte: Union[Unset, str] = UNSET
    if not isinstance(affects_flaw_created_dt_date_gte, Unset):
        json_affects_flaw_created_dt_date_gte = (
            affects_flaw_created_dt_date_gte.isoformat()
        )

    params["affects__flaw__created_dt__date__gte"] = (
        json_affects_flaw_created_dt_date_gte
    )

    json_affects_flaw_created_dt_date_lte: Union[Unset, str] = UNSET
    if not isinstance(affects_flaw_created_dt_date_lte, Unset):
        json_affects_flaw_created_dt_date_lte = (
            affects_flaw_created_dt_date_lte.isoformat()
        )

    params["affects__flaw__created_dt__date__lte"] = (
        json_affects_flaw_created_dt_date_lte
    )

    json_affects_flaw_created_dt_gt: Union[Unset, str] = UNSET
    if not isinstance(affects_flaw_created_dt_gt, Unset):
        json_affects_flaw_created_dt_gt = affects_flaw_created_dt_gt.isoformat()

    params["affects__flaw__created_dt__gt"] = json_affects_flaw_created_dt_gt

    json_affects_flaw_created_dt_gte: Union[Unset, str] = UNSET
    if not isinstance(affects_flaw_created_dt_gte, Unset):
        json_affects_flaw_created_dt_gte = affects_flaw_created_dt_gte.isoformat()

    params["affects__flaw__created_dt__gte"] = json_affects_flaw_created_dt_gte

    json_affects_flaw_created_dt_lt: Union[Unset, str] = UNSET
    if not isinstance(affects_flaw_created_dt_lt, Unset):
        json_affects_flaw_created_dt_lt = affects_flaw_created_dt_lt.isoformat()

    params["affects__flaw__created_dt__lt"] = json_affects_flaw_created_dt_lt

    json_affects_flaw_created_dt_lte: Union[Unset, str] = UNSET
    if not isinstance(affects_flaw_created_dt_lte, Unset):
        json_affects_flaw_created_dt_lte = affects_flaw_created_dt_lte.isoformat()

    params["affects__flaw__created_dt__lte"] = json_affects_flaw_created_dt_lte

    params["affects__flaw__cve_id"] = affects_flaw_cve_id

    params["affects__flaw__cwe_id"] = affects_flaw_cwe_id

    params["affects__flaw__embargoed"] = affects_flaw_embargoed

    params["affects__flaw__impact"] = affects_flaw_impact

    json_affects_flaw_reported_dt: Union[Unset, str] = UNSET
    if not isinstance(affects_flaw_reported_dt, Unset):
        json_affects_flaw_reported_dt = affects_flaw_reported_dt.isoformat()

    params["affects__flaw__reported_dt"] = json_affects_flaw_reported_dt

    json_affects_flaw_reported_dt_date: Union[Unset, str] = UNSET
    if not isinstance(affects_flaw_reported_dt_date, Unset):
        json_affects_flaw_reported_dt_date = affects_flaw_reported_dt_date.isoformat()

    params["affects__flaw__reported_dt__date"] = json_affects_flaw_reported_dt_date

    json_affects_flaw_reported_dt_date_gte: Union[Unset, str] = UNSET
    if not isinstance(affects_flaw_reported_dt_date_gte, Unset):
        json_affects_flaw_reported_dt_date_gte = (
            affects_flaw_reported_dt_date_gte.isoformat()
        )

    params["affects__flaw__reported_dt__date__gte"] = (
        json_affects_flaw_reported_dt_date_gte
    )

    json_affects_flaw_reported_dt_date_lte: Union[Unset, str] = UNSET
    if not isinstance(affects_flaw_reported_dt_date_lte, Unset):
        json_affects_flaw_reported_dt_date_lte = (
            affects_flaw_reported_dt_date_lte.isoformat()
        )

    params["affects__flaw__reported_dt__date__lte"] = (
        json_affects_flaw_reported_dt_date_lte
    )

    json_affects_flaw_reported_dt_gt: Union[Unset, str] = UNSET
    if not isinstance(affects_flaw_reported_dt_gt, Unset):
        json_affects_flaw_reported_dt_gt = affects_flaw_reported_dt_gt.isoformat()

    params["affects__flaw__reported_dt__gt"] = json_affects_flaw_reported_dt_gt

    json_affects_flaw_reported_dt_gte: Union[Unset, str] = UNSET
    if not isinstance(affects_flaw_reported_dt_gte, Unset):
        json_affects_flaw_reported_dt_gte = affects_flaw_reported_dt_gte.isoformat()

    params["affects__flaw__reported_dt__gte"] = json_affects_flaw_reported_dt_gte

    json_affects_flaw_reported_dt_lt: Union[Unset, str] = UNSET
    if not isinstance(affects_flaw_reported_dt_lt, Unset):
        json_affects_flaw_reported_dt_lt = affects_flaw_reported_dt_lt.isoformat()

    params["affects__flaw__reported_dt__lt"] = json_affects_flaw_reported_dt_lt

    json_affects_flaw_reported_dt_lte: Union[Unset, str] = UNSET
    if not isinstance(affects_flaw_reported_dt_lte, Unset):
        json_affects_flaw_reported_dt_lte = affects_flaw_reported_dt_lte.isoformat()

    params["affects__flaw__reported_dt__lte"] = json_affects_flaw_reported_dt_lte

    params["affects__flaw__source"] = affects_flaw_source

    json_affects_flaw_unembargo_dt: Union[Unset, str] = UNSET
    if not isinstance(affects_flaw_unembargo_dt, Unset):
        json_affects_flaw_unembargo_dt = affects_flaw_unembargo_dt.isoformat()

    params["affects__flaw__unembargo_dt"] = json_affects_flaw_unembargo_dt

    json_affects_flaw_updated_dt: Union[Unset, str] = UNSET
    if not isinstance(affects_flaw_updated_dt, Unset):
        json_affects_flaw_updated_dt = affects_flaw_updated_dt.isoformat()

    params["affects__flaw__updated_dt"] = json_affects_flaw_updated_dt

    json_affects_flaw_updated_dt_date: Union[Unset, str] = UNSET
    if not isinstance(affects_flaw_updated_dt_date, Unset):
        json_affects_flaw_updated_dt_date = affects_flaw_updated_dt_date.isoformat()

    params["affects__flaw__updated_dt__date"] = json_affects_flaw_updated_dt_date

    json_affects_flaw_updated_dt_date_gte: Union[Unset, str] = UNSET
    if not isinstance(affects_flaw_updated_dt_date_gte, Unset):
        json_affects_flaw_updated_dt_date_gte = (
            affects_flaw_updated_dt_date_gte.isoformat()
        )

    params["affects__flaw__updated_dt__date__gte"] = (
        json_affects_flaw_updated_dt_date_gte
    )

    json_affects_flaw_updated_dt_date_lte: Union[Unset, str] = UNSET
    if not isinstance(affects_flaw_updated_dt_date_lte, Unset):
        json_affects_flaw_updated_dt_date_lte = (
            affects_flaw_updated_dt_date_lte.isoformat()
        )

    params["affects__flaw__updated_dt__date__lte"] = (
        json_affects_flaw_updated_dt_date_lte
    )

    json_affects_flaw_updated_dt_gt: Union[Unset, str] = UNSET
    if not isinstance(affects_flaw_updated_dt_gt, Unset):
        json_affects_flaw_updated_dt_gt = affects_flaw_updated_dt_gt.isoformat()

    params["affects__flaw__updated_dt__gt"] = json_affects_flaw_updated_dt_gt

    json_affects_flaw_updated_dt_gte: Union[Unset, str] = UNSET
    if not isinstance(affects_flaw_updated_dt_gte, Unset):
        json_affects_flaw_updated_dt_gte = affects_flaw_updated_dt_gte.isoformat()

    params["affects__flaw__updated_dt__gte"] = json_affects_flaw_updated_dt_gte

    json_affects_flaw_updated_dt_lt: Union[Unset, str] = UNSET
    if not isinstance(affects_flaw_updated_dt_lt, Unset):
        json_affects_flaw_updated_dt_lt = affects_flaw_updated_dt_lt.isoformat()

    params["affects__flaw__updated_dt__lt"] = json_affects_flaw_updated_dt_lt

    json_affects_flaw_updated_dt_lte: Union[Unset, str] = UNSET
    if not isinstance(affects_flaw_updated_dt_lte, Unset):
        json_affects_flaw_updated_dt_lte = affects_flaw_updated_dt_lte.isoformat()

    params["affects__flaw__updated_dt__lte"] = json_affects_flaw_updated_dt_lte

    params["affects__flaw__uuid"] = affects_flaw_uuid

    params["affects__impact"] = affects_impact

    params["affects__ps_component"] = affects_ps_component

    params["affects__ps_module"] = affects_ps_module

    params["affects__resolution"] = affects_resolution

    json_affects_updated_dt: Union[Unset, str] = UNSET
    if not isinstance(affects_updated_dt, Unset):
        json_affects_updated_dt = affects_updated_dt.isoformat()

    params["affects__updated_dt"] = json_affects_updated_dt

    json_affects_updated_dt_date: Union[Unset, str] = UNSET
    if not isinstance(affects_updated_dt_date, Unset):
        json_affects_updated_dt_date = affects_updated_dt_date.isoformat()

    params["affects__updated_dt__date"] = json_affects_updated_dt_date

    json_affects_updated_dt_date_gte: Union[Unset, str] = UNSET
    if not isinstance(affects_updated_dt_date_gte, Unset):
        json_affects_updated_dt_date_gte = affects_updated_dt_date_gte.isoformat()

    params["affects__updated_dt__date__gte"] = json_affects_updated_dt_date_gte

    json_affects_updated_dt_date_lte: Union[Unset, str] = UNSET
    if not isinstance(affects_updated_dt_date_lte, Unset):
        json_affects_updated_dt_date_lte = affects_updated_dt_date_lte.isoformat()

    params["affects__updated_dt__date__lte"] = json_affects_updated_dt_date_lte

    json_affects_updated_dt_gt: Union[Unset, str] = UNSET
    if not isinstance(affects_updated_dt_gt, Unset):
        json_affects_updated_dt_gt = affects_updated_dt_gt.isoformat()

    params["affects__updated_dt__gt"] = json_affects_updated_dt_gt

    json_affects_updated_dt_gte: Union[Unset, str] = UNSET
    if not isinstance(affects_updated_dt_gte, Unset):
        json_affects_updated_dt_gte = affects_updated_dt_gte.isoformat()

    params["affects__updated_dt__gte"] = json_affects_updated_dt_gte

    json_affects_updated_dt_lt: Union[Unset, str] = UNSET
    if not isinstance(affects_updated_dt_lt, Unset):
        json_affects_updated_dt_lt = affects_updated_dt_lt.isoformat()

    params["affects__updated_dt__lt"] = json_affects_updated_dt_lt

    json_affects_updated_dt_lte: Union[Unset, str] = UNSET
    if not isinstance(affects_updated_dt_lte, Unset):
        json_affects_updated_dt_lte = affects_updated_dt_lte.isoformat()

    params["affects__updated_dt__lte"] = json_affects_updated_dt_lte

    params["affects__uuid"] = affects_uuid

    json_created_dt: Union[Unset, str] = UNSET
    if not isinstance(created_dt, Unset):
        json_created_dt = created_dt.isoformat()

    params["created_dt"] = json_created_dt

    json_created_dt_date: Union[Unset, str] = UNSET
    if not isinstance(created_dt_date, Unset):
        json_created_dt_date = created_dt_date.isoformat()

    params["created_dt__date"] = json_created_dt_date

    json_created_dt_date_gte: Union[Unset, str] = UNSET
    if not isinstance(created_dt_date_gte, Unset):
        json_created_dt_date_gte = created_dt_date_gte.isoformat()

    params["created_dt__date__gte"] = json_created_dt_date_gte

    json_created_dt_date_lte: Union[Unset, str] = UNSET
    if not isinstance(created_dt_date_lte, Unset):
        json_created_dt_date_lte = created_dt_date_lte.isoformat()

    params["created_dt__date__lte"] = json_created_dt_date_lte

    json_created_dt_gt: Union[Unset, str] = UNSET
    if not isinstance(created_dt_gt, Unset):
        json_created_dt_gt = created_dt_gt.isoformat()

    params["created_dt__gt"] = json_created_dt_gt

    json_created_dt_gte: Union[Unset, str] = UNSET
    if not isinstance(created_dt_gte, Unset):
        json_created_dt_gte = created_dt_gte.isoformat()

    params["created_dt__gte"] = json_created_dt_gte

    json_created_dt_lt: Union[Unset, str] = UNSET
    if not isinstance(created_dt_lt, Unset):
        json_created_dt_lt = created_dt_lt.isoformat()

    params["created_dt__lt"] = json_created_dt_lt

    json_created_dt_lte: Union[Unset, str] = UNSET
    if not isinstance(created_dt_lte, Unset):
        json_created_dt_lte = created_dt_lte.isoformat()

    params["created_dt__lte"] = json_created_dt_lte

    params["cve_id"] = cve_id

    params["embargoed"] = embargoed

    json_exclude_fields: Union[Unset, list[str]] = UNSET
    if not isinstance(exclude_fields, Unset):
        json_exclude_fields = exclude_fields

    params["exclude_fields"] = json_exclude_fields

    params["external_system_id"] = external_system_id

    json_include_fields: Union[Unset, list[str]] = UNSET
    if not isinstance(include_fields, Unset):
        json_include_fields = include_fields

    params["include_fields"] = json_include_fields

    json_include_meta_attr: Union[Unset, list[str]] = UNSET
    if not isinstance(include_meta_attr, Unset):
        json_include_meta_attr = include_meta_attr

    params["include_meta_attr"] = json_include_meta_attr

    params["limit"] = limit

    params["offset"] = offset

    json_order: Union[Unset, list[str]] = UNSET
    if not isinstance(order, Unset):
        json_order = []
        for order_item_data in order:
            order_item: str = UNSET
            if not isinstance(order_item_data, Unset):
                order_item = OsidbApiV1TrackersListOrderItem(order_item_data).value

            json_order.append(order_item)

    params["order"] = json_order

    params["ps_update_stream"] = ps_update_stream

    params["resolution"] = resolution

    params["status"] = status

    json_type_: Union[Unset, str] = UNSET
    if not isinstance(type_, Unset):
        json_type_ = OsidbApiV1TrackersListType(type_).value

    params["type"] = json_type_

    json_updated_dt: Union[Unset, str] = UNSET
    if not isinstance(updated_dt, Unset):
        json_updated_dt = updated_dt.isoformat()

    params["updated_dt"] = json_updated_dt

    json_updated_dt_date: Union[Unset, str] = UNSET
    if not isinstance(updated_dt_date, Unset):
        json_updated_dt_date = updated_dt_date.isoformat()

    params["updated_dt__date"] = json_updated_dt_date

    json_updated_dt_date_gte: Union[Unset, str] = UNSET
    if not isinstance(updated_dt_date_gte, Unset):
        json_updated_dt_date_gte = updated_dt_date_gte.isoformat()

    params["updated_dt__date__gte"] = json_updated_dt_date_gte

    json_updated_dt_date_lte: Union[Unset, str] = UNSET
    if not isinstance(updated_dt_date_lte, Unset):
        json_updated_dt_date_lte = updated_dt_date_lte.isoformat()

    params["updated_dt__date__lte"] = json_updated_dt_date_lte

    json_updated_dt_gt: Union[Unset, str] = UNSET
    if not isinstance(updated_dt_gt, Unset):
        json_updated_dt_gt = updated_dt_gt.isoformat()

    params["updated_dt__gt"] = json_updated_dt_gt

    json_updated_dt_gte: Union[Unset, str] = UNSET
    if not isinstance(updated_dt_gte, Unset):
        json_updated_dt_gte = updated_dt_gte.isoformat()

    params["updated_dt__gte"] = json_updated_dt_gte

    json_updated_dt_lt: Union[Unset, str] = UNSET
    if not isinstance(updated_dt_lt, Unset):
        json_updated_dt_lt = updated_dt_lt.isoformat()

    params["updated_dt__lt"] = json_updated_dt_lt

    json_updated_dt_lte: Union[Unset, str] = UNSET
    if not isinstance(updated_dt_lte, Unset):
        json_updated_dt_lte = updated_dt_lte.isoformat()

    params["updated_dt__lte"] = json_updated_dt_lte

    json_uuid: Union[Unset, str] = UNSET
    if not isinstance(uuid, Unset):
        json_uuid = str(uuid)

    params["uuid"] = json_uuid

    params = {
        k: (",".join(v) if isinstance(v, list) else v)
        for k, v in params.items()
        if v is not UNSET and v is not None
    }

    _kwargs: dict[str, Any] = {
        "url": f"{client.base_url}/osidb/api/v1/trackers",
        "params": params,
    }

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: requests.Response
) -> Optional[OsidbApiV1TrackersListResponse200]:
    if response.status_code == 200:
        _response_200 = response.json()
        response_200: OsidbApiV1TrackersListResponse200
        if isinstance(_response_200, Unset):
            response_200 = UNSET
        else:
            response_200 = OsidbApiV1TrackersListResponse200.from_dict(_response_200)

        return response_200


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: requests.Response
) -> Response[OsidbApiV1TrackersListResponse200]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    affects_affectedness: Union[Unset, str] = UNSET,
    affects_created_dt: Union[Unset, datetime.datetime] = UNSET,
    affects_created_dt_date: Union[Unset, datetime.date] = UNSET,
    affects_created_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    affects_created_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    affects_created_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    affects_created_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    affects_created_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    affects_created_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    affects_embargoed: Union[Unset, bool] = UNSET,
    affects_flaw_components: Union[Unset, list[str]] = UNSET,
    affects_flaw_created_dt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_created_dt_date: Union[Unset, datetime.date] = UNSET,
    affects_flaw_created_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    affects_flaw_created_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    affects_flaw_created_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_created_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_created_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_created_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_cve_id: Union[Unset, str] = UNSET,
    affects_flaw_cwe_id: Union[Unset, str] = UNSET,
    affects_flaw_embargoed: Union[Unset, bool] = UNSET,
    affects_flaw_impact: Union[Unset, str] = UNSET,
    affects_flaw_reported_dt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_reported_dt_date: Union[Unset, datetime.date] = UNSET,
    affects_flaw_reported_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    affects_flaw_reported_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    affects_flaw_reported_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_reported_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_reported_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_reported_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_source: Union[Unset, str] = UNSET,
    affects_flaw_unembargo_dt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_updated_dt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_updated_dt_date: Union[Unset, datetime.date] = UNSET,
    affects_flaw_updated_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    affects_flaw_updated_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    affects_flaw_updated_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_updated_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_updated_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_updated_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_uuid: Union[Unset, str] = UNSET,
    affects_impact: Union[Unset, str] = UNSET,
    affects_ps_component: Union[Unset, str] = UNSET,
    affects_ps_module: Union[Unset, str] = UNSET,
    affects_resolution: Union[Unset, str] = UNSET,
    affects_updated_dt: Union[Unset, datetime.datetime] = UNSET,
    affects_updated_dt_date: Union[Unset, datetime.date] = UNSET,
    affects_updated_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    affects_updated_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    affects_updated_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    affects_updated_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    affects_updated_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    affects_updated_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    affects_uuid: Union[Unset, str] = UNSET,
    created_dt: Union[Unset, datetime.datetime] = UNSET,
    created_dt_date: Union[Unset, datetime.date] = UNSET,
    created_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    created_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    created_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    created_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    created_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    created_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    cve_id: Union[Unset, str] = UNSET,
    embargoed: Union[Unset, bool] = UNSET,
    exclude_fields: Union[Unset, list[str]] = UNSET,
    external_system_id: Union[Unset, str] = UNSET,
    include_fields: Union[Unset, list[str]] = UNSET,
    include_meta_attr: Union[Unset, list[str]] = UNSET,
    limit: Union[Unset, int] = UNSET,
    offset: Union[Unset, int] = UNSET,
    order: Union[Unset, list[OsidbApiV1TrackersListOrderItem]] = UNSET,
    ps_update_stream: Union[Unset, str] = UNSET,
    resolution: Union[Unset, str] = UNSET,
    status: Union[Unset, str] = UNSET,
    type_: Union[Unset, OsidbApiV1TrackersListType] = UNSET,
    updated_dt: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_date: Union[Unset, datetime.date] = UNSET,
    updated_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    updated_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    updated_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    uuid: Union[Unset, UUID] = UNSET,
) -> Response[OsidbApiV1TrackersListResponse200]:
    """View for the tracker model adapted to affects v1

    Args:
        affects_affectedness (Union[Unset, str]):
        affects_created_dt (Union[Unset, datetime.datetime]):
        affects_created_dt_date (Union[Unset, datetime.date]):
        affects_created_dt_date_gte (Union[Unset, datetime.date]):
        affects_created_dt_date_lte (Union[Unset, datetime.date]):
        affects_created_dt_gt (Union[Unset, datetime.datetime]):
        affects_created_dt_gte (Union[Unset, datetime.datetime]):
        affects_created_dt_lt (Union[Unset, datetime.datetime]):
        affects_created_dt_lte (Union[Unset, datetime.datetime]):
        affects_embargoed (Union[Unset, bool]):
        affects_flaw_components (Union[Unset, list[str]]):
        affects_flaw_created_dt (Union[Unset, datetime.datetime]):
        affects_flaw_created_dt_date (Union[Unset, datetime.date]):
        affects_flaw_created_dt_date_gte (Union[Unset, datetime.date]):
        affects_flaw_created_dt_date_lte (Union[Unset, datetime.date]):
        affects_flaw_created_dt_gt (Union[Unset, datetime.datetime]):
        affects_flaw_created_dt_gte (Union[Unset, datetime.datetime]):
        affects_flaw_created_dt_lt (Union[Unset, datetime.datetime]):
        affects_flaw_created_dt_lte (Union[Unset, datetime.datetime]):
        affects_flaw_cve_id (Union[Unset, str]):
        affects_flaw_cwe_id (Union[Unset, str]):
        affects_flaw_embargoed (Union[Unset, bool]):
        affects_flaw_impact (Union[Unset, str]):
        affects_flaw_reported_dt (Union[Unset, datetime.datetime]):
        affects_flaw_reported_dt_date (Union[Unset, datetime.date]):
        affects_flaw_reported_dt_date_gte (Union[Unset, datetime.date]):
        affects_flaw_reported_dt_date_lte (Union[Unset, datetime.date]):
        affects_flaw_reported_dt_gt (Union[Unset, datetime.datetime]):
        affects_flaw_reported_dt_gte (Union[Unset, datetime.datetime]):
        affects_flaw_reported_dt_lt (Union[Unset, datetime.datetime]):
        affects_flaw_reported_dt_lte (Union[Unset, datetime.datetime]):
        affects_flaw_source (Union[Unset, str]):
        affects_flaw_unembargo_dt (Union[Unset, datetime.datetime]):
        affects_flaw_updated_dt (Union[Unset, datetime.datetime]):
        affects_flaw_updated_dt_date (Union[Unset, datetime.date]):
        affects_flaw_updated_dt_date_gte (Union[Unset, datetime.date]):
        affects_flaw_updated_dt_date_lte (Union[Unset, datetime.date]):
        affects_flaw_updated_dt_gt (Union[Unset, datetime.datetime]):
        affects_flaw_updated_dt_gte (Union[Unset, datetime.datetime]):
        affects_flaw_updated_dt_lt (Union[Unset, datetime.datetime]):
        affects_flaw_updated_dt_lte (Union[Unset, datetime.datetime]):
        affects_flaw_uuid (Union[Unset, str]):
        affects_impact (Union[Unset, str]):
        affects_ps_component (Union[Unset, str]):
        affects_ps_module (Union[Unset, str]):
        affects_resolution (Union[Unset, str]):
        affects_updated_dt (Union[Unset, datetime.datetime]):
        affects_updated_dt_date (Union[Unset, datetime.date]):
        affects_updated_dt_date_gte (Union[Unset, datetime.date]):
        affects_updated_dt_date_lte (Union[Unset, datetime.date]):
        affects_updated_dt_gt (Union[Unset, datetime.datetime]):
        affects_updated_dt_gte (Union[Unset, datetime.datetime]):
        affects_updated_dt_lt (Union[Unset, datetime.datetime]):
        affects_updated_dt_lte (Union[Unset, datetime.datetime]):
        affects_uuid (Union[Unset, str]):
        created_dt (Union[Unset, datetime.datetime]):
        created_dt_date (Union[Unset, datetime.date]):
        created_dt_date_gte (Union[Unset, datetime.date]):
        created_dt_date_lte (Union[Unset, datetime.date]):
        created_dt_gt (Union[Unset, datetime.datetime]):
        created_dt_gte (Union[Unset, datetime.datetime]):
        created_dt_lt (Union[Unset, datetime.datetime]):
        created_dt_lte (Union[Unset, datetime.datetime]):
        cve_id (Union[Unset, str]):
        embargoed (Union[Unset, bool]):
        exclude_fields (Union[Unset, list[str]]):
        external_system_id (Union[Unset, str]):
        include_fields (Union[Unset, list[str]]):
        include_meta_attr (Union[Unset, list[str]]):
        limit (Union[Unset, int]):
        offset (Union[Unset, int]):
        order (Union[Unset, list[OsidbApiV1TrackersListOrderItem]]):
        ps_update_stream (Union[Unset, str]):
        resolution (Union[Unset, str]):
        status (Union[Unset, str]):
        type_ (Union[Unset, OsidbApiV1TrackersListType]):
        updated_dt (Union[Unset, datetime.datetime]):
        updated_dt_date (Union[Unset, datetime.date]):
        updated_dt_date_gte (Union[Unset, datetime.date]):
        updated_dt_date_lte (Union[Unset, datetime.date]):
        updated_dt_gt (Union[Unset, datetime.datetime]):
        updated_dt_gte (Union[Unset, datetime.datetime]):
        updated_dt_lt (Union[Unset, datetime.datetime]):
        updated_dt_lte (Union[Unset, datetime.datetime]):
        uuid (Union[Unset, UUID]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[OsidbApiV1TrackersListResponse200]
    """

    kwargs = _get_kwargs(
        client=client,
        affects_affectedness=affects_affectedness,
        affects_created_dt=affects_created_dt,
        affects_created_dt_date=affects_created_dt_date,
        affects_created_dt_date_gte=affects_created_dt_date_gte,
        affects_created_dt_date_lte=affects_created_dt_date_lte,
        affects_created_dt_gt=affects_created_dt_gt,
        affects_created_dt_gte=affects_created_dt_gte,
        affects_created_dt_lt=affects_created_dt_lt,
        affects_created_dt_lte=affects_created_dt_lte,
        affects_embargoed=affects_embargoed,
        affects_flaw_components=affects_flaw_components,
        affects_flaw_created_dt=affects_flaw_created_dt,
        affects_flaw_created_dt_date=affects_flaw_created_dt_date,
        affects_flaw_created_dt_date_gte=affects_flaw_created_dt_date_gte,
        affects_flaw_created_dt_date_lte=affects_flaw_created_dt_date_lte,
        affects_flaw_created_dt_gt=affects_flaw_created_dt_gt,
        affects_flaw_created_dt_gte=affects_flaw_created_dt_gte,
        affects_flaw_created_dt_lt=affects_flaw_created_dt_lt,
        affects_flaw_created_dt_lte=affects_flaw_created_dt_lte,
        affects_flaw_cve_id=affects_flaw_cve_id,
        affects_flaw_cwe_id=affects_flaw_cwe_id,
        affects_flaw_embargoed=affects_flaw_embargoed,
        affects_flaw_impact=affects_flaw_impact,
        affects_flaw_reported_dt=affects_flaw_reported_dt,
        affects_flaw_reported_dt_date=affects_flaw_reported_dt_date,
        affects_flaw_reported_dt_date_gte=affects_flaw_reported_dt_date_gte,
        affects_flaw_reported_dt_date_lte=affects_flaw_reported_dt_date_lte,
        affects_flaw_reported_dt_gt=affects_flaw_reported_dt_gt,
        affects_flaw_reported_dt_gte=affects_flaw_reported_dt_gte,
        affects_flaw_reported_dt_lt=affects_flaw_reported_dt_lt,
        affects_flaw_reported_dt_lte=affects_flaw_reported_dt_lte,
        affects_flaw_source=affects_flaw_source,
        affects_flaw_unembargo_dt=affects_flaw_unembargo_dt,
        affects_flaw_updated_dt=affects_flaw_updated_dt,
        affects_flaw_updated_dt_date=affects_flaw_updated_dt_date,
        affects_flaw_updated_dt_date_gte=affects_flaw_updated_dt_date_gte,
        affects_flaw_updated_dt_date_lte=affects_flaw_updated_dt_date_lte,
        affects_flaw_updated_dt_gt=affects_flaw_updated_dt_gt,
        affects_flaw_updated_dt_gte=affects_flaw_updated_dt_gte,
        affects_flaw_updated_dt_lt=affects_flaw_updated_dt_lt,
        affects_flaw_updated_dt_lte=affects_flaw_updated_dt_lte,
        affects_flaw_uuid=affects_flaw_uuid,
        affects_impact=affects_impact,
        affects_ps_component=affects_ps_component,
        affects_ps_module=affects_ps_module,
        affects_resolution=affects_resolution,
        affects_updated_dt=affects_updated_dt,
        affects_updated_dt_date=affects_updated_dt_date,
        affects_updated_dt_date_gte=affects_updated_dt_date_gte,
        affects_updated_dt_date_lte=affects_updated_dt_date_lte,
        affects_updated_dt_gt=affects_updated_dt_gt,
        affects_updated_dt_gte=affects_updated_dt_gte,
        affects_updated_dt_lt=affects_updated_dt_lt,
        affects_updated_dt_lte=affects_updated_dt_lte,
        affects_uuid=affects_uuid,
        created_dt=created_dt,
        created_dt_date=created_dt_date,
        created_dt_date_gte=created_dt_date_gte,
        created_dt_date_lte=created_dt_date_lte,
        created_dt_gt=created_dt_gt,
        created_dt_gte=created_dt_gte,
        created_dt_lt=created_dt_lt,
        created_dt_lte=created_dt_lte,
        cve_id=cve_id,
        embargoed=embargoed,
        exclude_fields=exclude_fields,
        external_system_id=external_system_id,
        include_fields=include_fields,
        include_meta_attr=include_meta_attr,
        limit=limit,
        offset=offset,
        order=order,
        ps_update_stream=ps_update_stream,
        resolution=resolution,
        status=status,
        type_=type_,
        updated_dt=updated_dt,
        updated_dt_date=updated_dt_date,
        updated_dt_date_gte=updated_dt_date_gte,
        updated_dt_date_lte=updated_dt_date_lte,
        updated_dt_gt=updated_dt_gt,
        updated_dt_gte=updated_dt_gte,
        updated_dt_lt=updated_dt_lt,
        updated_dt_lte=updated_dt_lte,
        uuid=uuid,
    )

    response = requests.get(
        verify=client.verify_ssl,
        auth=client.auth,
        timeout=client.timeout,
        **kwargs,
    )
    response.raise_for_status()

    return _build_response(client=client, response=response)


def sync(
    *,
    client: AuthenticatedClient,
    affects_affectedness: Union[Unset, str] = UNSET,
    affects_created_dt: Union[Unset, datetime.datetime] = UNSET,
    affects_created_dt_date: Union[Unset, datetime.date] = UNSET,
    affects_created_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    affects_created_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    affects_created_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    affects_created_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    affects_created_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    affects_created_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    affects_embargoed: Union[Unset, bool] = UNSET,
    affects_flaw_components: Union[Unset, list[str]] = UNSET,
    affects_flaw_created_dt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_created_dt_date: Union[Unset, datetime.date] = UNSET,
    affects_flaw_created_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    affects_flaw_created_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    affects_flaw_created_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_created_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_created_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_created_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_cve_id: Union[Unset, str] = UNSET,
    affects_flaw_cwe_id: Union[Unset, str] = UNSET,
    affects_flaw_embargoed: Union[Unset, bool] = UNSET,
    affects_flaw_impact: Union[Unset, str] = UNSET,
    affects_flaw_reported_dt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_reported_dt_date: Union[Unset, datetime.date] = UNSET,
    affects_flaw_reported_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    affects_flaw_reported_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    affects_flaw_reported_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_reported_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_reported_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_reported_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_source: Union[Unset, str] = UNSET,
    affects_flaw_unembargo_dt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_updated_dt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_updated_dt_date: Union[Unset, datetime.date] = UNSET,
    affects_flaw_updated_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    affects_flaw_updated_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    affects_flaw_updated_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_updated_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_updated_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_updated_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_uuid: Union[Unset, str] = UNSET,
    affects_impact: Union[Unset, str] = UNSET,
    affects_ps_component: Union[Unset, str] = UNSET,
    affects_ps_module: Union[Unset, str] = UNSET,
    affects_resolution: Union[Unset, str] = UNSET,
    affects_updated_dt: Union[Unset, datetime.datetime] = UNSET,
    affects_updated_dt_date: Union[Unset, datetime.date] = UNSET,
    affects_updated_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    affects_updated_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    affects_updated_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    affects_updated_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    affects_updated_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    affects_updated_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    affects_uuid: Union[Unset, str] = UNSET,
    created_dt: Union[Unset, datetime.datetime] = UNSET,
    created_dt_date: Union[Unset, datetime.date] = UNSET,
    created_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    created_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    created_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    created_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    created_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    created_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    cve_id: Union[Unset, str] = UNSET,
    embargoed: Union[Unset, bool] = UNSET,
    exclude_fields: Union[Unset, list[str]] = UNSET,
    external_system_id: Union[Unset, str] = UNSET,
    include_fields: Union[Unset, list[str]] = UNSET,
    include_meta_attr: Union[Unset, list[str]] = UNSET,
    limit: Union[Unset, int] = UNSET,
    offset: Union[Unset, int] = UNSET,
    order: Union[Unset, list[OsidbApiV1TrackersListOrderItem]] = UNSET,
    ps_update_stream: Union[Unset, str] = UNSET,
    resolution: Union[Unset, str] = UNSET,
    status: Union[Unset, str] = UNSET,
    type_: Union[Unset, OsidbApiV1TrackersListType] = UNSET,
    updated_dt: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_date: Union[Unset, datetime.date] = UNSET,
    updated_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    updated_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    updated_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    uuid: Union[Unset, UUID] = UNSET,
) -> Optional[OsidbApiV1TrackersListResponse200]:
    """View for the tracker model adapted to affects v1

    Args:
        affects_affectedness (Union[Unset, str]):
        affects_created_dt (Union[Unset, datetime.datetime]):
        affects_created_dt_date (Union[Unset, datetime.date]):
        affects_created_dt_date_gte (Union[Unset, datetime.date]):
        affects_created_dt_date_lte (Union[Unset, datetime.date]):
        affects_created_dt_gt (Union[Unset, datetime.datetime]):
        affects_created_dt_gte (Union[Unset, datetime.datetime]):
        affects_created_dt_lt (Union[Unset, datetime.datetime]):
        affects_created_dt_lte (Union[Unset, datetime.datetime]):
        affects_embargoed (Union[Unset, bool]):
        affects_flaw_components (Union[Unset, list[str]]):
        affects_flaw_created_dt (Union[Unset, datetime.datetime]):
        affects_flaw_created_dt_date (Union[Unset, datetime.date]):
        affects_flaw_created_dt_date_gte (Union[Unset, datetime.date]):
        affects_flaw_created_dt_date_lte (Union[Unset, datetime.date]):
        affects_flaw_created_dt_gt (Union[Unset, datetime.datetime]):
        affects_flaw_created_dt_gte (Union[Unset, datetime.datetime]):
        affects_flaw_created_dt_lt (Union[Unset, datetime.datetime]):
        affects_flaw_created_dt_lte (Union[Unset, datetime.datetime]):
        affects_flaw_cve_id (Union[Unset, str]):
        affects_flaw_cwe_id (Union[Unset, str]):
        affects_flaw_embargoed (Union[Unset, bool]):
        affects_flaw_impact (Union[Unset, str]):
        affects_flaw_reported_dt (Union[Unset, datetime.datetime]):
        affects_flaw_reported_dt_date (Union[Unset, datetime.date]):
        affects_flaw_reported_dt_date_gte (Union[Unset, datetime.date]):
        affects_flaw_reported_dt_date_lte (Union[Unset, datetime.date]):
        affects_flaw_reported_dt_gt (Union[Unset, datetime.datetime]):
        affects_flaw_reported_dt_gte (Union[Unset, datetime.datetime]):
        affects_flaw_reported_dt_lt (Union[Unset, datetime.datetime]):
        affects_flaw_reported_dt_lte (Union[Unset, datetime.datetime]):
        affects_flaw_source (Union[Unset, str]):
        affects_flaw_unembargo_dt (Union[Unset, datetime.datetime]):
        affects_flaw_updated_dt (Union[Unset, datetime.datetime]):
        affects_flaw_updated_dt_date (Union[Unset, datetime.date]):
        affects_flaw_updated_dt_date_gte (Union[Unset, datetime.date]):
        affects_flaw_updated_dt_date_lte (Union[Unset, datetime.date]):
        affects_flaw_updated_dt_gt (Union[Unset, datetime.datetime]):
        affects_flaw_updated_dt_gte (Union[Unset, datetime.datetime]):
        affects_flaw_updated_dt_lt (Union[Unset, datetime.datetime]):
        affects_flaw_updated_dt_lte (Union[Unset, datetime.datetime]):
        affects_flaw_uuid (Union[Unset, str]):
        affects_impact (Union[Unset, str]):
        affects_ps_component (Union[Unset, str]):
        affects_ps_module (Union[Unset, str]):
        affects_resolution (Union[Unset, str]):
        affects_updated_dt (Union[Unset, datetime.datetime]):
        affects_updated_dt_date (Union[Unset, datetime.date]):
        affects_updated_dt_date_gte (Union[Unset, datetime.date]):
        affects_updated_dt_date_lte (Union[Unset, datetime.date]):
        affects_updated_dt_gt (Union[Unset, datetime.datetime]):
        affects_updated_dt_gte (Union[Unset, datetime.datetime]):
        affects_updated_dt_lt (Union[Unset, datetime.datetime]):
        affects_updated_dt_lte (Union[Unset, datetime.datetime]):
        affects_uuid (Union[Unset, str]):
        created_dt (Union[Unset, datetime.datetime]):
        created_dt_date (Union[Unset, datetime.date]):
        created_dt_date_gte (Union[Unset, datetime.date]):
        created_dt_date_lte (Union[Unset, datetime.date]):
        created_dt_gt (Union[Unset, datetime.datetime]):
        created_dt_gte (Union[Unset, datetime.datetime]):
        created_dt_lt (Union[Unset, datetime.datetime]):
        created_dt_lte (Union[Unset, datetime.datetime]):
        cve_id (Union[Unset, str]):
        embargoed (Union[Unset, bool]):
        exclude_fields (Union[Unset, list[str]]):
        external_system_id (Union[Unset, str]):
        include_fields (Union[Unset, list[str]]):
        include_meta_attr (Union[Unset, list[str]]):
        limit (Union[Unset, int]):
        offset (Union[Unset, int]):
        order (Union[Unset, list[OsidbApiV1TrackersListOrderItem]]):
        ps_update_stream (Union[Unset, str]):
        resolution (Union[Unset, str]):
        status (Union[Unset, str]):
        type_ (Union[Unset, OsidbApiV1TrackersListType]):
        updated_dt (Union[Unset, datetime.datetime]):
        updated_dt_date (Union[Unset, datetime.date]):
        updated_dt_date_gte (Union[Unset, datetime.date]):
        updated_dt_date_lte (Union[Unset, datetime.date]):
        updated_dt_gt (Union[Unset, datetime.datetime]):
        updated_dt_gte (Union[Unset, datetime.datetime]):
        updated_dt_lt (Union[Unset, datetime.datetime]):
        updated_dt_lte (Union[Unset, datetime.datetime]):
        uuid (Union[Unset, UUID]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        OsidbApiV1TrackersListResponse200
    """

    return sync_detailed(
        client=client,
        affects_affectedness=affects_affectedness,
        affects_created_dt=affects_created_dt,
        affects_created_dt_date=affects_created_dt_date,
        affects_created_dt_date_gte=affects_created_dt_date_gte,
        affects_created_dt_date_lte=affects_created_dt_date_lte,
        affects_created_dt_gt=affects_created_dt_gt,
        affects_created_dt_gte=affects_created_dt_gte,
        affects_created_dt_lt=affects_created_dt_lt,
        affects_created_dt_lte=affects_created_dt_lte,
        affects_embargoed=affects_embargoed,
        affects_flaw_components=affects_flaw_components,
        affects_flaw_created_dt=affects_flaw_created_dt,
        affects_flaw_created_dt_date=affects_flaw_created_dt_date,
        affects_flaw_created_dt_date_gte=affects_flaw_created_dt_date_gte,
        affects_flaw_created_dt_date_lte=affects_flaw_created_dt_date_lte,
        affects_flaw_created_dt_gt=affects_flaw_created_dt_gt,
        affects_flaw_created_dt_gte=affects_flaw_created_dt_gte,
        affects_flaw_created_dt_lt=affects_flaw_created_dt_lt,
        affects_flaw_created_dt_lte=affects_flaw_created_dt_lte,
        affects_flaw_cve_id=affects_flaw_cve_id,
        affects_flaw_cwe_id=affects_flaw_cwe_id,
        affects_flaw_embargoed=affects_flaw_embargoed,
        affects_flaw_impact=affects_flaw_impact,
        affects_flaw_reported_dt=affects_flaw_reported_dt,
        affects_flaw_reported_dt_date=affects_flaw_reported_dt_date,
        affects_flaw_reported_dt_date_gte=affects_flaw_reported_dt_date_gte,
        affects_flaw_reported_dt_date_lte=affects_flaw_reported_dt_date_lte,
        affects_flaw_reported_dt_gt=affects_flaw_reported_dt_gt,
        affects_flaw_reported_dt_gte=affects_flaw_reported_dt_gte,
        affects_flaw_reported_dt_lt=affects_flaw_reported_dt_lt,
        affects_flaw_reported_dt_lte=affects_flaw_reported_dt_lte,
        affects_flaw_source=affects_flaw_source,
        affects_flaw_unembargo_dt=affects_flaw_unembargo_dt,
        affects_flaw_updated_dt=affects_flaw_updated_dt,
        affects_flaw_updated_dt_date=affects_flaw_updated_dt_date,
        affects_flaw_updated_dt_date_gte=affects_flaw_updated_dt_date_gte,
        affects_flaw_updated_dt_date_lte=affects_flaw_updated_dt_date_lte,
        affects_flaw_updated_dt_gt=affects_flaw_updated_dt_gt,
        affects_flaw_updated_dt_gte=affects_flaw_updated_dt_gte,
        affects_flaw_updated_dt_lt=affects_flaw_updated_dt_lt,
        affects_flaw_updated_dt_lte=affects_flaw_updated_dt_lte,
        affects_flaw_uuid=affects_flaw_uuid,
        affects_impact=affects_impact,
        affects_ps_component=affects_ps_component,
        affects_ps_module=affects_ps_module,
        affects_resolution=affects_resolution,
        affects_updated_dt=affects_updated_dt,
        affects_updated_dt_date=affects_updated_dt_date,
        affects_updated_dt_date_gte=affects_updated_dt_date_gte,
        affects_updated_dt_date_lte=affects_updated_dt_date_lte,
        affects_updated_dt_gt=affects_updated_dt_gt,
        affects_updated_dt_gte=affects_updated_dt_gte,
        affects_updated_dt_lt=affects_updated_dt_lt,
        affects_updated_dt_lte=affects_updated_dt_lte,
        affects_uuid=affects_uuid,
        created_dt=created_dt,
        created_dt_date=created_dt_date,
        created_dt_date_gte=created_dt_date_gte,
        created_dt_date_lte=created_dt_date_lte,
        created_dt_gt=created_dt_gt,
        created_dt_gte=created_dt_gte,
        created_dt_lt=created_dt_lt,
        created_dt_lte=created_dt_lte,
        cve_id=cve_id,
        embargoed=embargoed,
        exclude_fields=exclude_fields,
        external_system_id=external_system_id,
        include_fields=include_fields,
        include_meta_attr=include_meta_attr,
        limit=limit,
        offset=offset,
        order=order,
        ps_update_stream=ps_update_stream,
        resolution=resolution,
        status=status,
        type_=type_,
        updated_dt=updated_dt,
        updated_dt_date=updated_dt_date,
        updated_dt_date_gte=updated_dt_date_gte,
        updated_dt_date_lte=updated_dt_date_lte,
        updated_dt_gt=updated_dt_gt,
        updated_dt_gte=updated_dt_gte,
        updated_dt_lt=updated_dt_lt,
        updated_dt_lte=updated_dt_lte,
        uuid=uuid,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    affects_affectedness: Union[Unset, str] = UNSET,
    affects_created_dt: Union[Unset, datetime.datetime] = UNSET,
    affects_created_dt_date: Union[Unset, datetime.date] = UNSET,
    affects_created_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    affects_created_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    affects_created_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    affects_created_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    affects_created_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    affects_created_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    affects_embargoed: Union[Unset, bool] = UNSET,
    affects_flaw_components: Union[Unset, list[str]] = UNSET,
    affects_flaw_created_dt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_created_dt_date: Union[Unset, datetime.date] = UNSET,
    affects_flaw_created_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    affects_flaw_created_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    affects_flaw_created_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_created_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_created_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_created_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_cve_id: Union[Unset, str] = UNSET,
    affects_flaw_cwe_id: Union[Unset, str] = UNSET,
    affects_flaw_embargoed: Union[Unset, bool] = UNSET,
    affects_flaw_impact: Union[Unset, str] = UNSET,
    affects_flaw_reported_dt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_reported_dt_date: Union[Unset, datetime.date] = UNSET,
    affects_flaw_reported_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    affects_flaw_reported_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    affects_flaw_reported_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_reported_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_reported_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_reported_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_source: Union[Unset, str] = UNSET,
    affects_flaw_unembargo_dt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_updated_dt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_updated_dt_date: Union[Unset, datetime.date] = UNSET,
    affects_flaw_updated_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    affects_flaw_updated_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    affects_flaw_updated_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_updated_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_updated_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_updated_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_uuid: Union[Unset, str] = UNSET,
    affects_impact: Union[Unset, str] = UNSET,
    affects_ps_component: Union[Unset, str] = UNSET,
    affects_ps_module: Union[Unset, str] = UNSET,
    affects_resolution: Union[Unset, str] = UNSET,
    affects_updated_dt: Union[Unset, datetime.datetime] = UNSET,
    affects_updated_dt_date: Union[Unset, datetime.date] = UNSET,
    affects_updated_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    affects_updated_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    affects_updated_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    affects_updated_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    affects_updated_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    affects_updated_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    affects_uuid: Union[Unset, str] = UNSET,
    created_dt: Union[Unset, datetime.datetime] = UNSET,
    created_dt_date: Union[Unset, datetime.date] = UNSET,
    created_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    created_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    created_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    created_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    created_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    created_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    cve_id: Union[Unset, str] = UNSET,
    embargoed: Union[Unset, bool] = UNSET,
    exclude_fields: Union[Unset, list[str]] = UNSET,
    external_system_id: Union[Unset, str] = UNSET,
    include_fields: Union[Unset, list[str]] = UNSET,
    include_meta_attr: Union[Unset, list[str]] = UNSET,
    limit: Union[Unset, int] = UNSET,
    offset: Union[Unset, int] = UNSET,
    order: Union[Unset, list[OsidbApiV1TrackersListOrderItem]] = UNSET,
    ps_update_stream: Union[Unset, str] = UNSET,
    resolution: Union[Unset, str] = UNSET,
    status: Union[Unset, str] = UNSET,
    type_: Union[Unset, OsidbApiV1TrackersListType] = UNSET,
    updated_dt: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_date: Union[Unset, datetime.date] = UNSET,
    updated_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    updated_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    updated_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    uuid: Union[Unset, UUID] = UNSET,
) -> Response[OsidbApiV1TrackersListResponse200]:
    """View for the tracker model adapted to affects v1

    Args:
        affects_affectedness (Union[Unset, str]):
        affects_created_dt (Union[Unset, datetime.datetime]):
        affects_created_dt_date (Union[Unset, datetime.date]):
        affects_created_dt_date_gte (Union[Unset, datetime.date]):
        affects_created_dt_date_lte (Union[Unset, datetime.date]):
        affects_created_dt_gt (Union[Unset, datetime.datetime]):
        affects_created_dt_gte (Union[Unset, datetime.datetime]):
        affects_created_dt_lt (Union[Unset, datetime.datetime]):
        affects_created_dt_lte (Union[Unset, datetime.datetime]):
        affects_embargoed (Union[Unset, bool]):
        affects_flaw_components (Union[Unset, list[str]]):
        affects_flaw_created_dt (Union[Unset, datetime.datetime]):
        affects_flaw_created_dt_date (Union[Unset, datetime.date]):
        affects_flaw_created_dt_date_gte (Union[Unset, datetime.date]):
        affects_flaw_created_dt_date_lte (Union[Unset, datetime.date]):
        affects_flaw_created_dt_gt (Union[Unset, datetime.datetime]):
        affects_flaw_created_dt_gte (Union[Unset, datetime.datetime]):
        affects_flaw_created_dt_lt (Union[Unset, datetime.datetime]):
        affects_flaw_created_dt_lte (Union[Unset, datetime.datetime]):
        affects_flaw_cve_id (Union[Unset, str]):
        affects_flaw_cwe_id (Union[Unset, str]):
        affects_flaw_embargoed (Union[Unset, bool]):
        affects_flaw_impact (Union[Unset, str]):
        affects_flaw_reported_dt (Union[Unset, datetime.datetime]):
        affects_flaw_reported_dt_date (Union[Unset, datetime.date]):
        affects_flaw_reported_dt_date_gte (Union[Unset, datetime.date]):
        affects_flaw_reported_dt_date_lte (Union[Unset, datetime.date]):
        affects_flaw_reported_dt_gt (Union[Unset, datetime.datetime]):
        affects_flaw_reported_dt_gte (Union[Unset, datetime.datetime]):
        affects_flaw_reported_dt_lt (Union[Unset, datetime.datetime]):
        affects_flaw_reported_dt_lte (Union[Unset, datetime.datetime]):
        affects_flaw_source (Union[Unset, str]):
        affects_flaw_unembargo_dt (Union[Unset, datetime.datetime]):
        affects_flaw_updated_dt (Union[Unset, datetime.datetime]):
        affects_flaw_updated_dt_date (Union[Unset, datetime.date]):
        affects_flaw_updated_dt_date_gte (Union[Unset, datetime.date]):
        affects_flaw_updated_dt_date_lte (Union[Unset, datetime.date]):
        affects_flaw_updated_dt_gt (Union[Unset, datetime.datetime]):
        affects_flaw_updated_dt_gte (Union[Unset, datetime.datetime]):
        affects_flaw_updated_dt_lt (Union[Unset, datetime.datetime]):
        affects_flaw_updated_dt_lte (Union[Unset, datetime.datetime]):
        affects_flaw_uuid (Union[Unset, str]):
        affects_impact (Union[Unset, str]):
        affects_ps_component (Union[Unset, str]):
        affects_ps_module (Union[Unset, str]):
        affects_resolution (Union[Unset, str]):
        affects_updated_dt (Union[Unset, datetime.datetime]):
        affects_updated_dt_date (Union[Unset, datetime.date]):
        affects_updated_dt_date_gte (Union[Unset, datetime.date]):
        affects_updated_dt_date_lte (Union[Unset, datetime.date]):
        affects_updated_dt_gt (Union[Unset, datetime.datetime]):
        affects_updated_dt_gte (Union[Unset, datetime.datetime]):
        affects_updated_dt_lt (Union[Unset, datetime.datetime]):
        affects_updated_dt_lte (Union[Unset, datetime.datetime]):
        affects_uuid (Union[Unset, str]):
        created_dt (Union[Unset, datetime.datetime]):
        created_dt_date (Union[Unset, datetime.date]):
        created_dt_date_gte (Union[Unset, datetime.date]):
        created_dt_date_lte (Union[Unset, datetime.date]):
        created_dt_gt (Union[Unset, datetime.datetime]):
        created_dt_gte (Union[Unset, datetime.datetime]):
        created_dt_lt (Union[Unset, datetime.datetime]):
        created_dt_lte (Union[Unset, datetime.datetime]):
        cve_id (Union[Unset, str]):
        embargoed (Union[Unset, bool]):
        exclude_fields (Union[Unset, list[str]]):
        external_system_id (Union[Unset, str]):
        include_fields (Union[Unset, list[str]]):
        include_meta_attr (Union[Unset, list[str]]):
        limit (Union[Unset, int]):
        offset (Union[Unset, int]):
        order (Union[Unset, list[OsidbApiV1TrackersListOrderItem]]):
        ps_update_stream (Union[Unset, str]):
        resolution (Union[Unset, str]):
        status (Union[Unset, str]):
        type_ (Union[Unset, OsidbApiV1TrackersListType]):
        updated_dt (Union[Unset, datetime.datetime]):
        updated_dt_date (Union[Unset, datetime.date]):
        updated_dt_date_gte (Union[Unset, datetime.date]):
        updated_dt_date_lte (Union[Unset, datetime.date]):
        updated_dt_gt (Union[Unset, datetime.datetime]):
        updated_dt_gte (Union[Unset, datetime.datetime]):
        updated_dt_lt (Union[Unset, datetime.datetime]):
        updated_dt_lte (Union[Unset, datetime.datetime]):
        uuid (Union[Unset, UUID]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[OsidbApiV1TrackersListResponse200]
    """

    kwargs = _get_kwargs(
        client=client,
        affects_affectedness=affects_affectedness,
        affects_created_dt=affects_created_dt,
        affects_created_dt_date=affects_created_dt_date,
        affects_created_dt_date_gte=affects_created_dt_date_gte,
        affects_created_dt_date_lte=affects_created_dt_date_lte,
        affects_created_dt_gt=affects_created_dt_gt,
        affects_created_dt_gte=affects_created_dt_gte,
        affects_created_dt_lt=affects_created_dt_lt,
        affects_created_dt_lte=affects_created_dt_lte,
        affects_embargoed=affects_embargoed,
        affects_flaw_components=affects_flaw_components,
        affects_flaw_created_dt=affects_flaw_created_dt,
        affects_flaw_created_dt_date=affects_flaw_created_dt_date,
        affects_flaw_created_dt_date_gte=affects_flaw_created_dt_date_gte,
        affects_flaw_created_dt_date_lte=affects_flaw_created_dt_date_lte,
        affects_flaw_created_dt_gt=affects_flaw_created_dt_gt,
        affects_flaw_created_dt_gte=affects_flaw_created_dt_gte,
        affects_flaw_created_dt_lt=affects_flaw_created_dt_lt,
        affects_flaw_created_dt_lte=affects_flaw_created_dt_lte,
        affects_flaw_cve_id=affects_flaw_cve_id,
        affects_flaw_cwe_id=affects_flaw_cwe_id,
        affects_flaw_embargoed=affects_flaw_embargoed,
        affects_flaw_impact=affects_flaw_impact,
        affects_flaw_reported_dt=affects_flaw_reported_dt,
        affects_flaw_reported_dt_date=affects_flaw_reported_dt_date,
        affects_flaw_reported_dt_date_gte=affects_flaw_reported_dt_date_gte,
        affects_flaw_reported_dt_date_lte=affects_flaw_reported_dt_date_lte,
        affects_flaw_reported_dt_gt=affects_flaw_reported_dt_gt,
        affects_flaw_reported_dt_gte=affects_flaw_reported_dt_gte,
        affects_flaw_reported_dt_lt=affects_flaw_reported_dt_lt,
        affects_flaw_reported_dt_lte=affects_flaw_reported_dt_lte,
        affects_flaw_source=affects_flaw_source,
        affects_flaw_unembargo_dt=affects_flaw_unembargo_dt,
        affects_flaw_updated_dt=affects_flaw_updated_dt,
        affects_flaw_updated_dt_date=affects_flaw_updated_dt_date,
        affects_flaw_updated_dt_date_gte=affects_flaw_updated_dt_date_gte,
        affects_flaw_updated_dt_date_lte=affects_flaw_updated_dt_date_lte,
        affects_flaw_updated_dt_gt=affects_flaw_updated_dt_gt,
        affects_flaw_updated_dt_gte=affects_flaw_updated_dt_gte,
        affects_flaw_updated_dt_lt=affects_flaw_updated_dt_lt,
        affects_flaw_updated_dt_lte=affects_flaw_updated_dt_lte,
        affects_flaw_uuid=affects_flaw_uuid,
        affects_impact=affects_impact,
        affects_ps_component=affects_ps_component,
        affects_ps_module=affects_ps_module,
        affects_resolution=affects_resolution,
        affects_updated_dt=affects_updated_dt,
        affects_updated_dt_date=affects_updated_dt_date,
        affects_updated_dt_date_gte=affects_updated_dt_date_gte,
        affects_updated_dt_date_lte=affects_updated_dt_date_lte,
        affects_updated_dt_gt=affects_updated_dt_gt,
        affects_updated_dt_gte=affects_updated_dt_gte,
        affects_updated_dt_lt=affects_updated_dt_lt,
        affects_updated_dt_lte=affects_updated_dt_lte,
        affects_uuid=affects_uuid,
        created_dt=created_dt,
        created_dt_date=created_dt_date,
        created_dt_date_gte=created_dt_date_gte,
        created_dt_date_lte=created_dt_date_lte,
        created_dt_gt=created_dt_gt,
        created_dt_gte=created_dt_gte,
        created_dt_lt=created_dt_lt,
        created_dt_lte=created_dt_lte,
        cve_id=cve_id,
        embargoed=embargoed,
        exclude_fields=exclude_fields,
        external_system_id=external_system_id,
        include_fields=include_fields,
        include_meta_attr=include_meta_attr,
        limit=limit,
        offset=offset,
        order=order,
        ps_update_stream=ps_update_stream,
        resolution=resolution,
        status=status,
        type_=type_,
        updated_dt=updated_dt,
        updated_dt_date=updated_dt_date,
        updated_dt_date_gte=updated_dt_date_gte,
        updated_dt_date_lte=updated_dt_date_lte,
        updated_dt_gt=updated_dt_gt,
        updated_dt_gte=updated_dt_gte,
        updated_dt_lt=updated_dt_lt,
        updated_dt_lte=updated_dt_lte,
        uuid=uuid,
    )

    async with client.get_async_session().get(
        verify_ssl=client.verify_ssl, raise_for_status=True, **kwargs
    ) as response:
        content = await response.read()
        resp = requests.Response()
        resp.status_code = response.status
        resp._content = content

    return _build_response(client=client, response=resp)


async def asyncio(
    *,
    client: AuthenticatedClient,
    affects_affectedness: Union[Unset, str] = UNSET,
    affects_created_dt: Union[Unset, datetime.datetime] = UNSET,
    affects_created_dt_date: Union[Unset, datetime.date] = UNSET,
    affects_created_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    affects_created_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    affects_created_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    affects_created_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    affects_created_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    affects_created_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    affects_embargoed: Union[Unset, bool] = UNSET,
    affects_flaw_components: Union[Unset, list[str]] = UNSET,
    affects_flaw_created_dt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_created_dt_date: Union[Unset, datetime.date] = UNSET,
    affects_flaw_created_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    affects_flaw_created_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    affects_flaw_created_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_created_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_created_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_created_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_cve_id: Union[Unset, str] = UNSET,
    affects_flaw_cwe_id: Union[Unset, str] = UNSET,
    affects_flaw_embargoed: Union[Unset, bool] = UNSET,
    affects_flaw_impact: Union[Unset, str] = UNSET,
    affects_flaw_reported_dt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_reported_dt_date: Union[Unset, datetime.date] = UNSET,
    affects_flaw_reported_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    affects_flaw_reported_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    affects_flaw_reported_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_reported_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_reported_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_reported_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_source: Union[Unset, str] = UNSET,
    affects_flaw_unembargo_dt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_updated_dt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_updated_dt_date: Union[Unset, datetime.date] = UNSET,
    affects_flaw_updated_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    affects_flaw_updated_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    affects_flaw_updated_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_updated_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_updated_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_updated_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    affects_flaw_uuid: Union[Unset, str] = UNSET,
    affects_impact: Union[Unset, str] = UNSET,
    affects_ps_component: Union[Unset, str] = UNSET,
    affects_ps_module: Union[Unset, str] = UNSET,
    affects_resolution: Union[Unset, str] = UNSET,
    affects_updated_dt: Union[Unset, datetime.datetime] = UNSET,
    affects_updated_dt_date: Union[Unset, datetime.date] = UNSET,
    affects_updated_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    affects_updated_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    affects_updated_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    affects_updated_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    affects_updated_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    affects_updated_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    affects_uuid: Union[Unset, str] = UNSET,
    created_dt: Union[Unset, datetime.datetime] = UNSET,
    created_dt_date: Union[Unset, datetime.date] = UNSET,
    created_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    created_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    created_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    created_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    created_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    created_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    cve_id: Union[Unset, str] = UNSET,
    embargoed: Union[Unset, bool] = UNSET,
    exclude_fields: Union[Unset, list[str]] = UNSET,
    external_system_id: Union[Unset, str] = UNSET,
    include_fields: Union[Unset, list[str]] = UNSET,
    include_meta_attr: Union[Unset, list[str]] = UNSET,
    limit: Union[Unset, int] = UNSET,
    offset: Union[Unset, int] = UNSET,
    order: Union[Unset, list[OsidbApiV1TrackersListOrderItem]] = UNSET,
    ps_update_stream: Union[Unset, str] = UNSET,
    resolution: Union[Unset, str] = UNSET,
    status: Union[Unset, str] = UNSET,
    type_: Union[Unset, OsidbApiV1TrackersListType] = UNSET,
    updated_dt: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_date: Union[Unset, datetime.date] = UNSET,
    updated_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    updated_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    updated_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    uuid: Union[Unset, UUID] = UNSET,
) -> Optional[OsidbApiV1TrackersListResponse200]:
    """View for the tracker model adapted to affects v1

    Args:
        affects_affectedness (Union[Unset, str]):
        affects_created_dt (Union[Unset, datetime.datetime]):
        affects_created_dt_date (Union[Unset, datetime.date]):
        affects_created_dt_date_gte (Union[Unset, datetime.date]):
        affects_created_dt_date_lte (Union[Unset, datetime.date]):
        affects_created_dt_gt (Union[Unset, datetime.datetime]):
        affects_created_dt_gte (Union[Unset, datetime.datetime]):
        affects_created_dt_lt (Union[Unset, datetime.datetime]):
        affects_created_dt_lte (Union[Unset, datetime.datetime]):
        affects_embargoed (Union[Unset, bool]):
        affects_flaw_components (Union[Unset, list[str]]):
        affects_flaw_created_dt (Union[Unset, datetime.datetime]):
        affects_flaw_created_dt_date (Union[Unset, datetime.date]):
        affects_flaw_created_dt_date_gte (Union[Unset, datetime.date]):
        affects_flaw_created_dt_date_lte (Union[Unset, datetime.date]):
        affects_flaw_created_dt_gt (Union[Unset, datetime.datetime]):
        affects_flaw_created_dt_gte (Union[Unset, datetime.datetime]):
        affects_flaw_created_dt_lt (Union[Unset, datetime.datetime]):
        affects_flaw_created_dt_lte (Union[Unset, datetime.datetime]):
        affects_flaw_cve_id (Union[Unset, str]):
        affects_flaw_cwe_id (Union[Unset, str]):
        affects_flaw_embargoed (Union[Unset, bool]):
        affects_flaw_impact (Union[Unset, str]):
        affects_flaw_reported_dt (Union[Unset, datetime.datetime]):
        affects_flaw_reported_dt_date (Union[Unset, datetime.date]):
        affects_flaw_reported_dt_date_gte (Union[Unset, datetime.date]):
        affects_flaw_reported_dt_date_lte (Union[Unset, datetime.date]):
        affects_flaw_reported_dt_gt (Union[Unset, datetime.datetime]):
        affects_flaw_reported_dt_gte (Union[Unset, datetime.datetime]):
        affects_flaw_reported_dt_lt (Union[Unset, datetime.datetime]):
        affects_flaw_reported_dt_lte (Union[Unset, datetime.datetime]):
        affects_flaw_source (Union[Unset, str]):
        affects_flaw_unembargo_dt (Union[Unset, datetime.datetime]):
        affects_flaw_updated_dt (Union[Unset, datetime.datetime]):
        affects_flaw_updated_dt_date (Union[Unset, datetime.date]):
        affects_flaw_updated_dt_date_gte (Union[Unset, datetime.date]):
        affects_flaw_updated_dt_date_lte (Union[Unset, datetime.date]):
        affects_flaw_updated_dt_gt (Union[Unset, datetime.datetime]):
        affects_flaw_updated_dt_gte (Union[Unset, datetime.datetime]):
        affects_flaw_updated_dt_lt (Union[Unset, datetime.datetime]):
        affects_flaw_updated_dt_lte (Union[Unset, datetime.datetime]):
        affects_flaw_uuid (Union[Unset, str]):
        affects_impact (Union[Unset, str]):
        affects_ps_component (Union[Unset, str]):
        affects_ps_module (Union[Unset, str]):
        affects_resolution (Union[Unset, str]):
        affects_updated_dt (Union[Unset, datetime.datetime]):
        affects_updated_dt_date (Union[Unset, datetime.date]):
        affects_updated_dt_date_gte (Union[Unset, datetime.date]):
        affects_updated_dt_date_lte (Union[Unset, datetime.date]):
        affects_updated_dt_gt (Union[Unset, datetime.datetime]):
        affects_updated_dt_gte (Union[Unset, datetime.datetime]):
        affects_updated_dt_lt (Union[Unset, datetime.datetime]):
        affects_updated_dt_lte (Union[Unset, datetime.datetime]):
        affects_uuid (Union[Unset, str]):
        created_dt (Union[Unset, datetime.datetime]):
        created_dt_date (Union[Unset, datetime.date]):
        created_dt_date_gte (Union[Unset, datetime.date]):
        created_dt_date_lte (Union[Unset, datetime.date]):
        created_dt_gt (Union[Unset, datetime.datetime]):
        created_dt_gte (Union[Unset, datetime.datetime]):
        created_dt_lt (Union[Unset, datetime.datetime]):
        created_dt_lte (Union[Unset, datetime.datetime]):
        cve_id (Union[Unset, str]):
        embargoed (Union[Unset, bool]):
        exclude_fields (Union[Unset, list[str]]):
        external_system_id (Union[Unset, str]):
        include_fields (Union[Unset, list[str]]):
        include_meta_attr (Union[Unset, list[str]]):
        limit (Union[Unset, int]):
        offset (Union[Unset, int]):
        order (Union[Unset, list[OsidbApiV1TrackersListOrderItem]]):
        ps_update_stream (Union[Unset, str]):
        resolution (Union[Unset, str]):
        status (Union[Unset, str]):
        type_ (Union[Unset, OsidbApiV1TrackersListType]):
        updated_dt (Union[Unset, datetime.datetime]):
        updated_dt_date (Union[Unset, datetime.date]):
        updated_dt_date_gte (Union[Unset, datetime.date]):
        updated_dt_date_lte (Union[Unset, datetime.date]):
        updated_dt_gt (Union[Unset, datetime.datetime]):
        updated_dt_gte (Union[Unset, datetime.datetime]):
        updated_dt_lt (Union[Unset, datetime.datetime]):
        updated_dt_lte (Union[Unset, datetime.datetime]):
        uuid (Union[Unset, UUID]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        OsidbApiV1TrackersListResponse200
    """

    return (
        await asyncio_detailed(
            client=client,
            affects_affectedness=affects_affectedness,
            affects_created_dt=affects_created_dt,
            affects_created_dt_date=affects_created_dt_date,
            affects_created_dt_date_gte=affects_created_dt_date_gte,
            affects_created_dt_date_lte=affects_created_dt_date_lte,
            affects_created_dt_gt=affects_created_dt_gt,
            affects_created_dt_gte=affects_created_dt_gte,
            affects_created_dt_lt=affects_created_dt_lt,
            affects_created_dt_lte=affects_created_dt_lte,
            affects_embargoed=affects_embargoed,
            affects_flaw_components=affects_flaw_components,
            affects_flaw_created_dt=affects_flaw_created_dt,
            affects_flaw_created_dt_date=affects_flaw_created_dt_date,
            affects_flaw_created_dt_date_gte=affects_flaw_created_dt_date_gte,
            affects_flaw_created_dt_date_lte=affects_flaw_created_dt_date_lte,
            affects_flaw_created_dt_gt=affects_flaw_created_dt_gt,
            affects_flaw_created_dt_gte=affects_flaw_created_dt_gte,
            affects_flaw_created_dt_lt=affects_flaw_created_dt_lt,
            affects_flaw_created_dt_lte=affects_flaw_created_dt_lte,
            affects_flaw_cve_id=affects_flaw_cve_id,
            affects_flaw_cwe_id=affects_flaw_cwe_id,
            affects_flaw_embargoed=affects_flaw_embargoed,
            affects_flaw_impact=affects_flaw_impact,
            affects_flaw_reported_dt=affects_flaw_reported_dt,
            affects_flaw_reported_dt_date=affects_flaw_reported_dt_date,
            affects_flaw_reported_dt_date_gte=affects_flaw_reported_dt_date_gte,
            affects_flaw_reported_dt_date_lte=affects_flaw_reported_dt_date_lte,
            affects_flaw_reported_dt_gt=affects_flaw_reported_dt_gt,
            affects_flaw_reported_dt_gte=affects_flaw_reported_dt_gte,
            affects_flaw_reported_dt_lt=affects_flaw_reported_dt_lt,
            affects_flaw_reported_dt_lte=affects_flaw_reported_dt_lte,
            affects_flaw_source=affects_flaw_source,
            affects_flaw_unembargo_dt=affects_flaw_unembargo_dt,
            affects_flaw_updated_dt=affects_flaw_updated_dt,
            affects_flaw_updated_dt_date=affects_flaw_updated_dt_date,
            affects_flaw_updated_dt_date_gte=affects_flaw_updated_dt_date_gte,
            affects_flaw_updated_dt_date_lte=affects_flaw_updated_dt_date_lte,
            affects_flaw_updated_dt_gt=affects_flaw_updated_dt_gt,
            affects_flaw_updated_dt_gte=affects_flaw_updated_dt_gte,
            affects_flaw_updated_dt_lt=affects_flaw_updated_dt_lt,
            affects_flaw_updated_dt_lte=affects_flaw_updated_dt_lte,
            affects_flaw_uuid=affects_flaw_uuid,
            affects_impact=affects_impact,
            affects_ps_component=affects_ps_component,
            affects_ps_module=affects_ps_module,
            affects_resolution=affects_resolution,
            affects_updated_dt=affects_updated_dt,
            affects_updated_dt_date=affects_updated_dt_date,
            affects_updated_dt_date_gte=affects_updated_dt_date_gte,
            affects_updated_dt_date_lte=affects_updated_dt_date_lte,
            affects_updated_dt_gt=affects_updated_dt_gt,
            affects_updated_dt_gte=affects_updated_dt_gte,
            affects_updated_dt_lt=affects_updated_dt_lt,
            affects_updated_dt_lte=affects_updated_dt_lte,
            affects_uuid=affects_uuid,
            created_dt=created_dt,
            created_dt_date=created_dt_date,
            created_dt_date_gte=created_dt_date_gte,
            created_dt_date_lte=created_dt_date_lte,
            created_dt_gt=created_dt_gt,
            created_dt_gte=created_dt_gte,
            created_dt_lt=created_dt_lt,
            created_dt_lte=created_dt_lte,
            cve_id=cve_id,
            embargoed=embargoed,
            exclude_fields=exclude_fields,
            external_system_id=external_system_id,
            include_fields=include_fields,
            include_meta_attr=include_meta_attr,
            limit=limit,
            offset=offset,
            order=order,
            ps_update_stream=ps_update_stream,
            resolution=resolution,
            status=status,
            type_=type_,
            updated_dt=updated_dt,
            updated_dt_date=updated_dt_date,
            updated_dt_date_gte=updated_dt_date_gte,
            updated_dt_date_lte=updated_dt_date_lte,
            updated_dt_gt=updated_dt_gt,
            updated_dt_gte=updated_dt_gte,
            updated_dt_lt=updated_dt_lt,
            updated_dt_lte=updated_dt_lte,
            uuid=uuid,
        )
    ).parsed



import datetime
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from attrs import fields as _attrs_fields
from dateutil.parser import isoparse

from ..types import UNSET, OSIDBModel, Unset

T = TypeVar("T", bound="CommentRequest")


@_attrs_define
class CommentRequest(OSIDBModel):
    """FlawComment serializer for use by FlawSerializer

    Attributes:
        text (str):
        updated_dt (datetime.datetime): The updated_dt timestamp attribute is mandatory on update as it is used to
            detect mit-air collisions.
        external_system_id (Union[Unset, str]):
        order (Union[None, Unset, int]):
        creator (Union[Unset, str]):
        is_private (Union[Unset, bool]):
    """

    text: str
    updated_dt: datetime.datetime
    external_system_id: Union[Unset, str] = UNSET
    order: Union[None, Unset, int] = UNSET
    creator: Union[Unset, str] = UNSET
    is_private: Union[Unset, bool] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        text = self.text

        updated_dt: str = UNSET
        if not isinstance(self.updated_dt, Unset):
            updated_dt = self.updated_dt.isoformat()

        external_system_id = self.external_system_id

        order: Union[None, Unset, int]
        if isinstance(self.order, Unset):
            order = UNSET
        else:
            order = self.order

        creator = self.creator

        is_private = self.is_private

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if not isinstance(text, Unset):
            field_dict["text"] = text
        if not isinstance(updated_dt, Unset):
            field_dict["updated_dt"] = updated_dt
        if not isinstance(external_system_id, Unset):
            field_dict["external_system_id"] = external_system_id
        if not isinstance(order, Unset):
            field_dict["order"] = order
        if not isinstance(creator, Unset):
            field_dict["creator"] = creator
        if not isinstance(is_private, Unset):
            field_dict["is_private"] = is_private

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        d = src_dict.copy()
        text = d.pop("text", UNSET)

        _updated_dt = d.pop("updated_dt", UNSET)
        updated_dt: datetime.datetime
        if isinstance(_updated_dt, Unset):
            updated_dt = UNSET
        else:
            updated_dt = isoparse(_updated_dt)

        external_system_id = d.pop("external_system_id", UNSET)

        def _parse_order(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        order = _parse_order(d.pop("order", UNSET))

        creator = d.pop("creator", UNSET)

        is_private = d.pop("is_private", UNSET)

        comment_request = cls(
            text=text,
            updated_dt=updated_dt,
            external_system_id=external_system_id,
            order=order,
            creator=creator,
            is_private=is_private,
        )

        comment_request.additional_properties = d
        return comment_request

    @classmethod
    def get_fields(cls):
        return {f.name: f.type for f in _attrs_fields(cls)}

    @classmethod
    def new(cls):
        return cls.from_dict({})

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from attrs import fields as _attrs_fields
from dateutil.parser import isoparse

from ..models.affectedness_enum import AffectednessEnum
from ..models.blank_enum import BlankEnum
from ..models.impact_enum import ImpactEnum
from ..models.not_affected_justification_enum import NotAffectedJustificationEnum
from ..models.resolution_enum import ResolutionEnum
from ..types import UNSET, OSIDBModel, Unset

if TYPE_CHECKING:
    from ..models.affect_cvss import AffectCVSS
    from ..models.alert import Alert
    from ..models.tracker import Tracker


T = TypeVar("T", bound="OsidbApiV2AffectsCreateResponse201")


@_attrs_define
class OsidbApiV2AffectsCreateResponse201(OSIDBModel):
    """
    Attributes:
        uuid (UUID):
        flaw (UUID):
        ps_update_stream (str):
        cve_id (str):
        ps_product (str):
        tracker (Union['Tracker', None]):
        delegated_resolution (str):
        cvss_scores (list['AffectCVSS']):
        delegated_not_affected_justification (str):
        resolved_dt (Union[None, datetime.datetime]):
        labels (list[str]):
        embargoed (bool): The embargoed boolean attribute is technically read-only as it just indirectly modifies the
            ACLs but is mandatory as it controls the access to the resource.
        alerts (list['Alert']):
        created_dt (datetime.datetime):
        updated_dt (datetime.datetime): The updated_dt timestamp attribute is mandatory on update as it is used to
            detect mit-air collisions.
        affectedness (Union[AffectednessEnum, BlankEnum, Unset]):
        resolution (Union[BlankEnum, ResolutionEnum, Unset]):
        ps_module (Union[Unset, str]):
        ps_component (Union[None, Unset, str]):
        impact (Union[BlankEnum, ImpactEnum, Unset]):
        purl (Union[None, Unset, str]):
        not_affected_justification (Union[BlankEnum, NotAffectedJustificationEnum, Unset]):
        dt (Union[Unset, datetime.datetime]):
        env (Union[Unset, str]):
        revision (Union[Unset, str]):
        version (Union[Unset, str]):
    """

    uuid: UUID
    flaw: UUID
    ps_update_stream: str
    cve_id: str
    ps_product: str
    tracker: Union["Tracker", None]
    delegated_resolution: str
    cvss_scores: list["AffectCVSS"]
    delegated_not_affected_justification: str
    resolved_dt: Union[None, datetime.datetime]
    labels: list[str]
    embargoed: bool
    alerts: list["Alert"]
    created_dt: datetime.datetime
    updated_dt: datetime.datetime
    affectedness: Union[AffectednessEnum, BlankEnum, Unset] = UNSET
    resolution: Union[BlankEnum, ResolutionEnum, Unset] = UNSET
    ps_module: Union[Unset, str] = UNSET
    ps_component: Union[None, Unset, str] = UNSET
    impact: Union[BlankEnum, ImpactEnum, Unset] = UNSET
    purl: Union[None, Unset, str] = UNSET
    not_affected_justification: Union[
        BlankEnum, NotAffectedJustificationEnum, Unset
    ] = UNSET
    dt: Union[Unset, datetime.datetime] = UNSET
    env: Union[Unset, str] = UNSET
    revision: Union[Unset, str] = UNSET
    version: Union[Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        from ..models.tracker import Tracker

        uuid: str = UNSET
        if not isinstance(self.uuid, Unset):
            uuid = str(self.uuid)

        flaw: str = UNSET
        if not isinstance(self.flaw, Unset):
            flaw = str(self.flaw)

        ps_update_stream = self.ps_update_stream

        cve_id = self.cve_id

        ps_product = self.ps_product

        tracker: Union[None, dict[str, Any]]
        if isinstance(self.tracker, Unset):
            tracker = UNSET
        elif isinstance(self.tracker, Tracker):
            tracker = UNSET
            if not isinstance(self.tracker, Unset):
                tracker = self.tracker.to_dict()

        else:
            tracker = self.tracker

        delegated_resolution = self.delegated_resolution

        cvss_scores: list[dict[str, Any]] = UNSET
        if not isinstance(self.cvss_scores, Unset):
            cvss_scores = []
            for cvss_scores_item_data in self.cvss_scores:
                cvss_scores_item: dict[str, Any] = UNSET
                if not isinstance(cvss_scores_item_data, Unset):
                    cvss_scores_item = cvss_scores_item_data.to_dict()

                cvss_scores.append(cvss_scores_item)

        delegated_not_affected_justification = self.delegated_not_affected_justification

        resolved_dt: Union[None, str]
        if isinstance(self.resolved_dt, Unset):
            resolved_dt = UNSET
        elif isinstance(self.resolved_dt, datetime.datetime):
            resolved_dt = UNSET
            if not isinstance(self.resolved_dt, Unset):
                resolved_dt = self.resolved_dt.isoformat()

        else:
            resolved_dt = self.resolved_dt

        labels: list[str] = UNSET
        if not isinstance(self.labels, Unset):
            labels = self.labels

        embargoed = self.embargoed

        alerts: list[dict[str, Any]] = UNSET
        if not isinstance(self.alerts, Unset):
            alerts = []
            for alerts_item_data in self.alerts:
                alerts_item: dict[str, Any] = UNSET
                if not isinstance(alerts_item_data, Unset):
                    alerts_item = alerts_item_data.to_dict()

                alerts.append(alerts_item)

        created_dt: str = UNSET
        if not isinstance(self.created_dt, Unset):
            created_dt = self.created_dt.isoformat()

        updated_dt: str = UNSET
        if not isinstance(self.updated_dt, Unset):
            updated_dt = self.updated_dt.isoformat()

        affectedness: Union[Unset, str]
        if isinstance(self.affectedness, Unset):
            affectedness = UNSET
        elif isinstance(self.affectedness, AffectednessEnum):
            affectedness = UNSET
            if not isinstance(self.affectedness, Unset):
                affectedness = AffectednessEnum(self.affectedness).value

        else:
            affectedness = UNSET
            if not isinstance(self.affectedness, Unset):
                affectedness = BlankEnum(self.affectedness).value

        resolution: Union[Unset, str]
        if isinstance(self.resolution, Unset):
            resolution = UNSET
        elif isinstance(self.resolution, ResolutionEnum):
            resolution = UNSET
            if not isinstance(self.resolution, Unset):
                resolution = ResolutionEnum(self.resolution).value

        else:
            resolution = UNSET
            if not isinstance(self.resolution, Unset):
                resolution = BlankEnum(self.resolution).value

        ps_module = self.ps_module

        ps_component: Union[None, Unset, str]
        if isinstance(self.ps_component, Unset):
            ps_component = UNSET
        else:
            ps_component = self.ps_component

        impact: Union[Unset, str]
        if isinstance(self.impact, Unset):
            impact = UNSET
        elif isinstance(self.impact, ImpactEnum):
            impact = UNSET
            if not isinstance(self.impact, Unset):
                impact = ImpactEnum(self.impact).value

        else:
            impact = UNSET
            if not isinstance(self.impact, Unset):
                impact = BlankEnum(self.impact).value

        purl: Union[None, Unset, str]
        if isinstance(self.purl, Unset):
            purl = UNSET
        else:
            purl = self.purl

        not_affected_justification: Union[Unset, str]
        if isinstance(self.not_affected_justification, Unset):
            not_affected_justification = UNSET
        elif isinstance(self.not_affected_justification, NotAffectedJustificationEnum):
            not_affected_justification = UNSET
            if not isinstance(self.not_affected_justification, Unset):
                not_affected_justification = NotAffectedJustificationEnum(
                    self.not_affected_justification
                ).value

        else:
            not_affected_justification = UNSET
            if not isinstance(self.not_affected_justification, Unset):
                not_affected_justification = BlankEnum(
                    self.not_affected_justification
                ).value

        dt: Union[Unset, str] = UNSET
        if not isinstance(self.dt, Unset):
            dt = self.dt.isoformat()

        env = self.env

        revision = self.revision

        version = self.version

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if not isinstance(uuid, Unset):
            field_dict["uuid"] = uuid
        if not isinstance(flaw, Unset):
            field_dict["flaw"] = flaw
        if not isinstance(ps_update_stream, Unset):
            field_dict["ps_update_stream"] = ps_update_stream
        if not isinstance(cve_id, Unset):
            field_dict["cve_id"] = cve_id
        if not isinstance(ps_product, Unset):
            field_dict["ps_product"] = ps_product
        if not isinstance(tracker, Unset):
            field_dict["tracker"] = tracker
        if not isinstance(delegated_resolution, Unset):
            field_dict["delegated_resolution"] = delegated_resolution
        if not isinstance(cvss_scores, Unset):
            field_dict["cvss_scores"] = cvss_scores
        if not isinstance(delegated_not_affected_justification, Unset):
            field_dict["delegated_not_affected_justification"] = (
                delegated_not_affected_justification
            )
        if not isinstance(resolved_dt, Unset):
            field_dict["resolved_dt"] = resolved_dt
        if not isinstance(labels, Unset):
            field_dict["labels"] = labels
        if not isinstance(embargoed, Unset):
            field_dict["embargoed"] = embargoed
        if not isinstance(alerts, Unset):
            field_dict["alerts"] = alerts
        if not isinstance(created_dt, Unset):
            field_dict["created_dt"] = created_dt
        if not isinstance(updated_dt, Unset):
            field_dict["updated_dt"] = updated_dt
        if not isinstance(affectedness, Unset):
            field_dict["affectedness"] = affectedness
        if not isinstance(resolution, Unset):
            field_dict["resolution"] = resolution
        if not isinstance(ps_module, Unset):
            field_dict["ps_module"] = ps_module
        if not isinstance(ps_component, Unset):
            field_dict["ps_component"] = ps_component
        if not isinstance(impact, Unset):
            field_dict["impact"] = impact
        if not isinstance(purl, Unset):
            field_dict["purl"] = purl
        if not isinstance(not_affected_justification, Unset):
            field_dict["not_affected_justification"] = not_affected_justification
        if not isinstance(dt, Unset):
            field_dict["dt"] = dt
        if not isinstance(env, Unset):
            field_dict["env"] = env
        if not isinstance(revision, Unset):
            field_dict["revision"] = revision
        if not isinstance(version, Unset):
            field_dict["version"] = version

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        from ..models.affect_cvss import AffectCVSS
        from ..models.alert import Alert
        from ..models.tracker import Tracker

        d = src_dict.copy()
        _uuid = d.pop("uuid", UNSET)
        uuid: UUID
        if isinstance(_uuid, Unset):
            uuid = UNSET
        else:
            uuid = _uuid if isinstance(_uuid, UUID) else UUID(_uuid)

        _flaw = d.pop("flaw", UNSET)
        flaw: UUID
        if isinstance(_flaw, Unset):
            flaw = UNSET
        else:
            flaw = _flaw if isinstance(_flaw, UUID) else UUID(_flaw)

        ps_update_stream = d.pop("ps_update_stream", UNSET)

        cve_id = d.pop("cve_id", UNSET)

        ps_product = d.pop("ps_product", UNSET)

        def _parse_tracker(data: object) -> Union["Tracker", None]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                _tracker_type_1 = data
                tracker_type_1: Tracker
                if isinstance(_tracker_type_1, Unset):
                    tracker_type_1 = UNSET
                else:
                    tracker_type_1 = Tracker.from_dict(_tracker_type_1)

                return tracker_type_1
            except:  # noqa: E722
                pass
            return cast(Union["Tracker", None], data)

        tracker = _parse_tracker(d.pop("tracker", UNSET))

        delegated_resolution = d.pop("delegated_resolution", UNSET)

        cvss_scores = []
        _cvss_scores = d.pop("cvss_scores", UNSET)
        for cvss_scores_item_data in _cvss_scores or []:
            _cvss_scores_item = cvss_scores_item_data
            cvss_scores_item: AffectCVSS
            if isinstance(_cvss_scores_item, Unset):
                cvss_scores_item = UNSET
            else:
                cvss_scores_item = AffectCVSS.from_dict(_cvss_scores_item)

            cvss_scores.append(cvss_scores_item)

        delegated_not_affected_justification = d.pop(
            "delegated_not_affected_justification", UNSET
        )

        def _parse_resolved_dt(data: object) -> Union[None, datetime.datetime]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                _resolved_dt_type_0 = data
                resolved_dt_type_0: datetime.datetime
                if isinstance(_resolved_dt_type_0, Unset):
                    resolved_dt_type_0 = UNSET
                else:
                    resolved_dt_type_0 = isoparse(_resolved_dt_type_0)

                return resolved_dt_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, datetime.datetime], data)

        resolved_dt = _parse_resolved_dt(d.pop("resolved_dt", UNSET))

        labels = cast(list[str], d.pop("labels", UNSET))

        embargoed = d.pop("embargoed", UNSET)

        alerts = []
        _alerts = d.pop("alerts", UNSET)
        for alerts_item_data in _alerts or []:
            _alerts_item = alerts_item_data
            alerts_item: Alert
            if isinstance(_alerts_item, Unset):
                alerts_item = UNSET
            else:
                alerts_item = Alert.from_dict(_alerts_item)

            alerts.append(alerts_item)

        _created_dt = d.pop("created_dt", UNSET)
        created_dt: datetime.datetime
        if isinstance(_created_dt, Unset):
            created_dt = UNSET
        else:
            created_dt = isoparse(_created_dt)

        _updated_dt = d.pop("updated_dt", UNSET)
        updated_dt: datetime.datetime
        if isinstance(_updated_dt, Unset):
            updated_dt = UNSET
        else:
            updated_dt = isoparse(_updated_dt)

        def _parse_affectedness(
            data: object,
        ) -> Union[AffectednessEnum, BlankEnum, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                _affectedness_type_0 = data
                affectedness_type_0: AffectednessEnum
                if isinstance(_affectedness_type_0, Unset):
                    affectedness_type_0 = UNSET
                else:
                    affectedness_type_0 = AffectednessEnum(_affectedness_type_0)

                return affectedness_type_0
            except:  # noqa: E722
                pass
            if not isinstance(data, str):
                raise TypeError()
            _affectedness_type_1 = data
            affectedness_type_1: BlankEnum
            if isinstance(_affectedness_type_1, Unset):
                affectedness_type_1 = UNSET
            else:
                affectedness_type_1 = BlankEnum(_affectedness_type_1)

            return affectedness_type_1

        affectedness = _parse_affectedness(d.pop("affectedness", UNSET))

        def _parse_resolution(data: object) -> Union[BlankEnum, ResolutionEnum, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                _resolution_type_0 = data
                resolution_type_0: ResolutionEnum
                if isinstance(_resolution_type_0, Unset):
                    resolution_type_0 = UNSET
                else:
                    resolution_type_0 = ResolutionEnum(_resolution_type_0)

                return resolution_type_0
            except:  # noqa: E722
                pass
            if not isinstance(data, str):
                raise TypeError()
            _resolution_type_1 = data
            resolution_type_1: BlankEnum
            if isinstance(_resolution_type_1, Unset):
                resolution_type_1 = UNSET
            else:
                resolution_type_1 = BlankEnum(_resolution_type_1)

            return resolution_type_1

        resolution = _parse_resolution(d.pop("resolution", UNSET))

        ps_module = d.pop("ps_module", UNSET)

        def _parse_ps_component(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        ps_component = _parse_ps_component(d.pop("ps_component", UNSET))

        def _parse_impact(data: object) -> Union[BlankEnum, ImpactEnum, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                _impact_type_0 = data
                impact_type_0: ImpactEnum
                if isinstance(_impact_type_0, Unset):
                    impact_type_0 = UNSET
                else:
                    impact_type_0 = ImpactEnum(_impact_type_0)

                return impact_type_0
            except:  # noqa: E722
                pass
            if not isinstance(data, str):
                raise TypeError()
            _impact_type_1 = data
            impact_type_1: BlankEnum
            if isinstance(_impact_type_1, Unset):
                impact_type_1 = UNSET
            else:
                impact_type_1 = BlankEnum(_impact_type_1)

            return impact_type_1

        impact = _parse_impact(d.pop("impact", UNSET))

        def _parse_purl(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        purl = _parse_purl(d.pop("purl", UNSET))

        def _parse_not_affected_justification(
            data: object,
        ) -> Union[BlankEnum, NotAffectedJustificationEnum, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                _not_affected_justification_type_0 = data
                not_affected_justification_type_0: NotAffectedJustificationEnum
                if isinstance(_not_affected_justification_type_0, Unset):
                    not_affected_justification_type_0 = UNSET
                else:
                    not_affected_justification_type_0 = NotAffectedJustificationEnum(
                        _not_affected_justification_type_0
                    )

                return not_affected_justification_type_0
            except:  # noqa: E722
                pass
            if not isinstance(data, str):
                raise TypeError()
            _not_affected_justification_type_1 = data
            not_affected_justification_type_1: BlankEnum
            if isinstance(_not_affected_justification_type_1, Unset):
                not_affected_justification_type_1 = UNSET
            else:
                not_affected_justification_type_1 = BlankEnum(
                    _not_affected_justification_type_1
                )

            return not_affected_justification_type_1

        not_affected_justification = _parse_not_affected_justification(
            d.pop("not_affected_justification", UNSET)
        )

        _dt = d.pop("dt", UNSET)
        dt: Union[Unset, datetime.datetime]
        if isinstance(_dt, Unset):
            dt = UNSET
        else:
            dt = isoparse(_dt)

        env = d.pop("env", UNSET)

        revision = d.pop("revision", UNSET)

        version = d.pop("version", UNSET)

        osidb_api_v2_affects_create_response_201 = cls(
            uuid=uuid,
            flaw=flaw,
            ps_update_stream=ps_update_stream,
            cve_id=cve_id,
            ps_product=ps_product,
            tracker=tracker,
            delegated_resolution=delegated_resolution,
            cvss_scores=cvss_scores,
            delegated_not_affected_justification=delegated_not_affected_justification,
            resolved_dt=resolved_dt,
            labels=labels,
            embargoed=embargoed,
            alerts=alerts,
            created_dt=created_dt,
            updated_dt=updated_dt,
            affectedness=affectedness,
            resolution=resolution,
            ps_module=ps_module,
            ps_component=ps_component,
            impact=impact,
            purl=purl,
            not_affected_justification=not_affected_justification,
            dt=dt,
            env=env,
            revision=revision,
            version=version,
        )

        osidb_api_v2_affects_create_response_201.additional_properties = d
        return osidb_api_v2_affects_create_response_201

    @classmethod
    def get_fields(cls):
        return {f.name: f.type for f in _attrs_fields(cls)}

    @classmethod
    def new(cls):
        return cls.from_dict({})

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from attrs import fields as _attrs_fields

from ..types import UNSET, OSIDBModel, Unset

T = TypeVar("T", bound="TokenVerifyRequest")


@_attrs_define
class TokenVerifyRequest(OSIDBModel):
    """
    Attributes:
        token (str):
    """

    token: str
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        token = self.token

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if not isinstance(token, Unset):
            field_dict["token"] = token

        return field_dict

    def to_multipart(self) -> dict[str, Any]:
        token = (None, str(self.token).encode(), "text/plain")

        field_dict: dict[str, Any] = {}
        for prop_name, prop in self.additional_properties.items():
            field_dict[prop_name] = (None, str(prop).encode(), "text/plain")

        if not isinstance(token, Unset):
            field_dict["token"] = token

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        d = src_dict.copy()
        token = d.pop("token", UNSET)

        token_verify_request = cls(
            token=token,
        )

        token_verify_request.additional_properties = d
        return token_verify_request

    @classmethod
    def get_fields(cls):
        return {f.name: f.type for f in _attrs_fields(cls)}

    @classmethod
    def new(cls):
        return cls.from_dict({})

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
import json
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from attrs import fields as _attrs_fields
from dateutil.parser import isoparse

from ..types import UNSET, OSIDBModel, Unset

if TYPE_CHECKING:
    from ..models.flaw_version_request import FlawVersionRequest


T = TypeVar("T", bound="FlawPackageVersionPutRequest")


@_attrs_define
class FlawPackageVersionPutRequest(OSIDBModel):
    """Package model serializer

    Attributes:
        package (str):
        versions (list['FlawVersionRequest']):
        embargoed (bool): The embargoed boolean attribute is technically read-only as it just indirectly modifies the
            ACLs but is mandatory as it controls the access to the resource.
        updated_dt (datetime.datetime): The updated_dt timestamp attribute is mandatory on update as it is used to
            detect mit-air collisions.
    """

    package: str
    versions: list["FlawVersionRequest"]
    embargoed: bool
    updated_dt: datetime.datetime
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        package = self.package

        versions: list[dict[str, Any]] = UNSET
        if not isinstance(self.versions, Unset):
            versions = []
            for versions_item_data in self.versions:
                versions_item: dict[str, Any] = UNSET
                if not isinstance(versions_item_data, Unset):
                    versions_item = versions_item_data.to_dict()

                versions.append(versions_item)

        embargoed = self.embargoed

        updated_dt: str = UNSET
        if not isinstance(self.updated_dt, Unset):
            updated_dt = self.updated_dt.isoformat()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if not isinstance(package, Unset):
            field_dict["package"] = package
        if not isinstance(versions, Unset):
            field_dict["versions"] = versions
        if not isinstance(embargoed, Unset):
            field_dict["embargoed"] = embargoed
        if not isinstance(updated_dt, Unset):
            field_dict["updated_dt"] = updated_dt

        return field_dict

    def to_multipart(self) -> dict[str, Any]:
        package = (None, str(self.package).encode(), "text/plain")

        versions: Union[Unset, tuple[None, bytes, str]] = UNSET
        if not isinstance(self.versions, Unset):
            _temp_versions = []
            for versions_item_data in self.versions:
                versions_item: dict[str, Any] = UNSET
                if not isinstance(versions_item_data, Unset):
                    versions_item = versions_item_data.to_dict()

                _temp_versions.append(versions_item)
            versions = (None, json.dumps(_temp_versions).encode(), "application/json")

        embargoed = (None, str(self.embargoed).encode(), "text/plain")

        updated_dt: bytes = UNSET
        if not isinstance(self.updated_dt, Unset):
            updated_dt = self.updated_dt.isoformat().encode()

        field_dict: dict[str, Any] = {}
        for prop_name, prop in self.additional_properties.items():
            field_dict[prop_name] = (None, str(prop).encode(), "text/plain")

        if not isinstance(package, Unset):
            field_dict["package"] = package
        if not isinstance(versions, Unset):
            field_dict["versions"] = versions
        if not isinstance(embargoed, Unset):
            field_dict["embargoed"] = embargoed
        if not isinstance(updated_dt, Unset):
            field_dict["updated_dt"] = updated_dt

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        from ..models.flaw_version_request import FlawVersionRequest

        d = src_dict.copy()
        package = d.pop("package", UNSET)

        versions = []
        _versions = d.pop("versions", UNSET)
        for versions_item_data in _versions or []:
            _versions_item = versions_item_data
            versions_item: FlawVersionRequest
            if isinstance(_versions_item, Unset):
                versions_item = UNSET
            else:
                versions_item = FlawVersionRequest.from_dict(_versions_item)

            versions.append(versions_item)

        embargoed = d.pop("embargoed", UNSET)

        _updated_dt = d.pop("updated_dt", UNSET)
        updated_dt: datetime.datetime
        if isinstance(_updated_dt, Unset):
            updated_dt = UNSET
        else:
            updated_dt = isoparse(_updated_dt)

        flaw_package_version_put_request = cls(
            package=package,
            versions=versions,
            embargoed=embargoed,
            updated_dt=updated_dt,
        )

        flaw_package_version_put_request.additional_properties = d
        return flaw_package_version_put_request

    @classmethod
    def get_fields(cls):
        return {f.name: f.type for f in _attrs_fields(cls)}

    @classmethod
    def new(cls):
        return cls.from_dict({})

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from attrs import fields as _attrs_fields

from ..models.state_enum import StateEnum
from ..types import UNSET, OSIDBModel, Unset

T = TypeVar("T", bound="FlawCollaboratorPostRequest")


@_attrs_define
class FlawCollaboratorPostRequest(OSIDBModel):
    """FlawCollaborator serializer

    Attributes:
        label (str):
        state (Union[Unset, StateEnum]):
        contributor (Union[Unset, str]):
    """

    label: str
    state: Union[Unset, StateEnum] = UNSET
    contributor: Union[Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        label = self.label

        state: Union[Unset, str] = UNSET
        if not isinstance(self.state, Unset):
            state = StateEnum(self.state).value

        contributor = self.contributor

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if not isinstance(label, Unset):
            field_dict["label"] = label
        if not isinstance(state, Unset):
            field_dict["state"] = state
        if not isinstance(contributor, Unset):
            field_dict["contributor"] = contributor

        return field_dict

    def to_multipart(self) -> dict[str, Any]:
        label = (None, str(self.label).encode(), "text/plain")

        state: Union[Unset, tuple[None, bytes, str]] = UNSET
        if not isinstance(self.state, Unset):
            state = (None, str(self.state.value).encode(), "text/plain")

        contributor = (
            self.contributor
            if isinstance(self.contributor, Unset)
            else (None, str(self.contributor).encode(), "text/plain")
        )

        field_dict: dict[str, Any] = {}
        for prop_name, prop in self.additional_properties.items():
            field_dict[prop_name] = (None, str(prop).encode(), "text/plain")

        if not isinstance(label, Unset):
            field_dict["label"] = label
        if not isinstance(state, Unset):
            field_dict["state"] = state
        if not isinstance(contributor, Unset):
            field_dict["contributor"] = contributor

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        d = src_dict.copy()
        label = d.pop("label", UNSET)

        _state = d.pop("state", UNSET)
        state: Union[Unset, StateEnum]
        if isinstance(_state, Unset):
            state = UNSET
        else:
            state = StateEnum(_state)

        contributor = d.pop("contributor", UNSET)

        flaw_collaborator_post_request = cls(
            label=label,
            state=state,
            contributor=contributor,
        )

        flaw_collaborator_post_request.additional_properties = d
        return flaw_collaborator_post_request

    @classmethod
    def get_fields(cls):
        return {f.name: f.type for f in _attrs_fields(cls)}

    @classmethod
    def new(cls):
        return cls.from_dict({})

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import json
from typing import Any, TypeVar, Union
from uuid import UUID

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from attrs import fields as _attrs_fields

from ..types import UNSET, OSIDBModel, Unset

T = TypeVar("T", bound="FlawUUIDListRequest")


@_attrs_define
class FlawUUIDListRequest(OSIDBModel):
    """
    Attributes:
        flaw_uuids (list[UUID]):
    """

    flaw_uuids: list[UUID]
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        flaw_uuids: list[str] = UNSET
        if not isinstance(self.flaw_uuids, Unset):
            flaw_uuids = []
            for flaw_uuids_item_data in self.flaw_uuids:
                flaw_uuids_item: str = UNSET
                if not isinstance(flaw_uuids_item_data, Unset):
                    flaw_uuids_item = str(flaw_uuids_item_data)

                flaw_uuids.append(flaw_uuids_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if not isinstance(flaw_uuids, Unset):
            field_dict["flaw_uuids"] = flaw_uuids

        return field_dict

    def to_multipart(self) -> dict[str, Any]:
        flaw_uuids: Union[Unset, tuple[None, bytes, str]] = UNSET
        if not isinstance(self.flaw_uuids, Unset):
            _temp_flaw_uuids = []
            for flaw_uuids_item_data in self.flaw_uuids:
                flaw_uuids_item: str = UNSET
                if not isinstance(flaw_uuids_item_data, Unset):
                    flaw_uuids_item = str(flaw_uuids_item_data)

                _temp_flaw_uuids.append(flaw_uuids_item)
            flaw_uuids = (
                None,
                json.dumps(_temp_flaw_uuids).encode(),
                "application/json",
            )

        field_dict: dict[str, Any] = {}
        for prop_name, prop in self.additional_properties.items():
            field_dict[prop_name] = (None, str(prop).encode(), "text/plain")

        if not isinstance(flaw_uuids, Unset):
            field_dict["flaw_uuids"] = flaw_uuids

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        d = src_dict.copy()
        flaw_uuids = []
        _flaw_uuids = d.pop("flaw_uuids", UNSET)
        for flaw_uuids_item_data in _flaw_uuids or []:
            _flaw_uuids_item = flaw_uuids_item_data
            flaw_uuids_item: UUID
            if isinstance(_flaw_uuids_item, Unset):
                flaw_uuids_item = UNSET
            else:
                flaw_uuids_item = (
                    _flaw_uuids_item
                    if isinstance(_flaw_uuids_item, UUID)
                    else UUID(_flaw_uuids_item)
                )

            flaw_uuids.append(flaw_uuids_item)

        flaw_uuid_list_request = cls(
            flaw_uuids=flaw_uuids,
        )

        flaw_uuid_list_request.additional_properties = d
        return flaw_uuid_list_request

    @classmethod
    def get_fields(cls):
        return {f.name: f.type for f in _attrs_fields(cls)}

    @classmethod
    def new(cls):
        return cls.from_dict({})

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
